@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2014 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@ $Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 #include "../version/version.h"
 #include "../processeventblocker.h"
 #include "../connectors/connectoritem.h"
+#include "../connectors/svgidlayer.h"
 
 #include "cmrouter/tileutils.h"
 
@@ -55,6 +56,7 @@ $Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 static int OutlineLayer = 0;
 static int SilkTopLayer = 0;
 static QString PanelizerOutputPath;
+static QSet<QString> PanelizerFileNames;
 
 ///////////////////////////////////////////////////////////
 
@@ -227,7 +229,9 @@ PanelItem::PanelItem(PanelItem * from) {
 
 void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool customPartsOnly) 
 {
-    initPanelizerOutput(panelFilename);
+    QString msg = "panelize";
+    if (customPartsOnly) msg += " custom parts";
+    initPanelizerOutput(panelFilename, msg);
 
 	QFile panelizerFile(panelFilename);
 
@@ -432,6 +436,20 @@ void Panelizer::panelize(FApplication * app, const QString & panelFilename, bool
 
 		TextUtils::mergeSvg(doc, merger, "");
 		merger = TextUtils::mergeSvgFinish(doc);
+
+        int endix = merger.lastIndexOf("</svg>");
+        QString text = "<text x='%1' y='%2' text-anchor='end' fill='#000000' stroke='none' stroke-width='0' font-size='250' font-family='OCRA'>%3 panel %4  %5 %6</text>\n";
+        text = text
+                .arg(planePair->panelWidth * GraphicsUtils::StandardFritzingDPI)
+                .arg(planePair->panelHeight * GraphicsUtils::StandardFritzingDPI + (250 / 2))
+                .arg(outputDir.dirName())
+                .arg(planePair->index)
+                .arg(panelParams.prefix)
+                .arg(QTime::currentTime().toString())
+                ;
+
+        merger.insert(endix, text);
+
 		QString fname = svgDir.absoluteFilePath(QString("%1.%2.svg").arg(prefix).arg("identification"));
 		TextUtils::writeUtf8(fname, merger);
 
@@ -838,12 +856,12 @@ bool Panelizer::openWindows(QDomElement & boardElement, QHash<QString, QString>
             return false;
         }
 
-		MainWindow * mainWindow = app->openWindowForService(false);
+		MainWindow * mainWindow = app->openWindowForService(false, 3);
         mainWindow->setCloseSilently(true);
 
 		FolderUtils::setOpenSaveFolderAux(fzDir.absolutePath());
 
-		if (!mainWindow->loadWhich(copyPath, false, false, "")) {
+		if (!mainWindow->loadWhich(copyPath, false, false, false, "")) {
 			writePanelizerOutput(QString("failed to load '%1'").arg(copyPath));
 			return false;
 		}
@@ -862,7 +880,6 @@ bool Panelizer::openWindows(QDomElement & boardElement, QHash<QString, QString>
 			continue;
         }
         
-		mainWindow->showPCBView();
 		foreach (QGraphicsItem * item, mainWindow->pcbView()->scene()->items()) {
 			ItemBase * itemBase = dynamic_cast<ItemBase *>(item);
 			if (itemBase == NULL) continue;
@@ -1239,9 +1256,9 @@ void Panelizer::addOptional(int optionalCount, QList<PanelItem *> & refPanelItem
 
 /////////////////////////////////////////////////////////////////////////////////
 
-void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool drc) 
+void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool drc, bool noMessages) 
 {
-    initPanelizerOutput(panelFilename);
+    initPanelizerOutput(panelFilename, "inscribe");
 
 	QFile file(panelFilename);
 
@@ -1316,7 +1333,7 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 
 	board = boards.firstChildElement("board");
 	while (!board.isNull()) {
-		MainWindow * mainWindow = inscribeBoard(board, fzzFilePaths, app, fzDir, drc, copyDir);
+		MainWindow * mainWindow = inscribeBoard(board, fzzFilePaths, app, fzDir, drc, noMessages, copyDir);
 		if (mainWindow) {
 			mainWindow->setCloseSilently(true);
 			mainWindow->close();
@@ -1325,11 +1342,13 @@ void Panelizer::inscribe(FApplication * app, const QString & panelFilename, bool
 		board = board.nextSiblingElement("board");
 	}
 
+    writePanelizerFilenames(panelFilename);
+
 	// TODO: delete temp fz folder
 
 }
 
-MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QString> & fzzFilePaths, FApplication * app, QDir & fzDir, bool drc, QDir & copyDir)
+MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QString> & fzzFilePaths, FApplication * app, QDir & fzDir, bool drc, bool noMessages, QDir & copyDir)
 {
 	QString boardName = board.attribute("name");
 	int optional = board.attribute("maxOptionalCount", "").toInt();
@@ -1356,29 +1375,36 @@ MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QStrin
     }
 
     QFile file(originalPath);
-    QFile::remove(copyPath);
-    bool ok = file.copy(copyPath);
+    bool ok = FolderUtils::slamCopy(file, copyPath);
     if (!ok) {
         QMessageBox::warning(NULL, QObject::tr("Fritzing"), QObject::tr("unable to copy file '%1' to '%2'.").arg(originalPath).arg(copyPath));
         return NULL;
     }
 
-	MainWindow * mainWindow = app->openWindowForService(false);
+	MainWindow * mainWindow = app->openWindowForService(false, 3);
 
 	FolderUtils::setOpenSaveFolderAux(fzDir.absolutePath());
 
-	if (!mainWindow->loadWhich(copyPath, false, false, "")) {
+	if (!mainWindow->loadWhich(copyPath, false, false, false, "")) {
 		writePanelizerOutput(QString("failed to load '%1'").arg(copyPath));
 		return mainWindow;
 	}
 
-	mainWindow->showPCBView();
+    QList<ItemBase *> items = mainWindow->pcbView()->selectAllObsolete();
+	if (items.count() > 0) {
+        QFileInfo info(copyPath);
+        writePanelizerOutput(QString("%2 ... %1 obsolete items").arg(items.count()).arg(info.fileName()));
+    }
 
     int moved = mainWindow->pcbView()->checkLoadedTraces();
     if (moved > 0) {
-        QString message = QObject::tr("%1 wires moved from their saved position in %2.").arg(moved).arg(originalPath);
-        QMessageBox::warning(NULL, QObject::tr("Fritzing"), message);
+        QFileInfo info(originalPath);
+        QString message = QObject::tr("%2 ... %1 wires moved from their saved position").arg(moved).arg(info.fileName());
+        if (!noMessages) {
+            QMessageBox::warning(NULL, QObject::tr("Fritzing"), message);
+        }
         writePanelizerOutput(message); 
+        collectFilenames(info.fileName());
     }
 
 	foreach (QGraphicsItem * item, mainWindow->pcbView()->scene()->items()) {
@@ -1433,8 +1459,8 @@ MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QStrin
 		DebugDialog::debug(QString("%1 filled:%2").arg(copyPath).arg(filled));
 	}
 
-    checkDonuts(mainWindow, true);
-    checkText(mainWindow, true);
+    checkDonuts(mainWindow, !noMessages);
+    checkText(mainWindow, !noMessages);
 
     if (drc) {
 	    foreach (ItemBase * boardItem, boards) {
@@ -1443,7 +1469,8 @@ MainWindow * Panelizer::inscribeBoard(QDomElement & board, QHash<QString, QStrin
             QStringList messages = mainWindow->newDesignRulesCheck(false);
             if (messages.count() > 0) {
                 QFileInfo info(mainWindow->fileName());
-                writePanelizerOutput(QString("%1 drc complaints on %2").arg(messages.count()).arg(info.fileName()));
+                writePanelizerOutput(QString("%2 ... %1 drc complaints").arg(messages.count()).arg(info.fileName()));
+                collectFilenames(info.fileName());
                 //foreach (QString message, messages) {
                 //    writePanelizerOutput("\t" + message);
                 //}
@@ -1711,7 +1738,11 @@ int Panelizer::checkText(MainWindow * mainWindow, bool displayMessage) {
     }
 
     if (missing.count() > 0) {
-        writePanelizerOutput(QString("There are %1 possible instances of parts with <path> elements missing stroke/fill/stroke-width attributes in %2").arg(missing.count()).arg(mainWindow->fileName()));
+        QFileInfo info(mainWindow->fileName());
+        writePanelizerOutput(QString("%2 ... There are %1 possible instances of parts with <path> elements missing stroke/fill/stroke-width attributes")
+                .arg(missing.count()).arg(info.fileName())
+            );
+        collectFilenames(info.fileName());
     }
 
     return  missing.count();
@@ -1742,12 +1773,15 @@ int Panelizer::checkDonuts(MainWindow * mainWindow, bool displayMessage) {
     }
 
     if (donuts.count() > 0) {
-        writePanelizerOutput(QString("%1 possible donuts in %2").arg(donuts.count() / 2).arg(mainWindow->fileName()));
+        QFileInfo info(mainWindow->fileName());
+        writePanelizerOutput(QString("%2 ... %1 possible donuts").arg(donuts.count() / 2).arg(info.fileName()));
+        collectFilenames(mainWindow->fileName());
     }
 
     return donuts.count() / 2;
 }
 
+
 int Panelizer::bestFitLoop(QList<PanelItem *> & refPanelItems, PanelParams & panelParams, bool customPartsOnly, QList<PlanePair *> & returnPlanePairs, QList<PanelItem *> & returnInsertPanelItems, const QDir & svgDir) 
 {
 	int optionalCount = 0;
@@ -1863,7 +1897,37 @@ void Panelizer::writePanelizerOutput(const QString & message) {
     }
 }
 
-void Panelizer::initPanelizerOutput(const QString & panelFilename) {
+void Panelizer::initPanelizerOutput(const QString & panelFilename, const QString & msg) {
+    PanelizerFileNames.clear();
     QFileInfo info(panelFilename);
     PanelizerOutputPath = info.absoluteDir().absoluteFilePath("panelizer_output.txt");
+
+    QDateTime dt = QDateTime::currentDateTime();
+    writePanelizerOutput(QString("\n--------- %1 --- %2 ---")
+                            .arg(msg).arg(dt.toString())
+                        );
+}
+
+void Panelizer::collectFilenames(const QString & filename) {
+    if (filename.endsWith(".fz")) {
+        PanelizerFileNames.insert(filename + "z");
+    }
+    else PanelizerFileNames.insert(filename);
+}
+
+void Panelizer::writePanelizerFilenames(const QString & panelFilename) {
+    if (PanelizerFileNames.count() == 0) return;
+
+    QFileInfo info(panelFilename);
+    QDateTime dt = QDateTime::currentDateTime();
+    QString path = info.absoluteDir().absoluteFilePath("panelizer_files_%1.txt").arg(dt.toString().replace(":", "."));
+    QFile file(path);
+    if (file.open(QFile::WriteOnly)) {
+        QTextStream out(&file);
+		out.setCodec("UTF-8");
+        foreach (QString name, PanelizerFileNames) {
+            out << name << "\n";
+        }
+        file.close();
+    }
 }
