@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6459 $:
+$Revision: 6955 $:
 $Author: irascibl@gmail.com $:
-$Date: 2012-09-20 11:09:45 +0200 (Thu, 20 Sep 2012) $
+$Date: 2013-04-06 23:14:37 +0200 (Sa, 06. Apr 2013) $
 
 ********************************************************************/
 
@@ -46,10 +46,12 @@ public:
 	void addConnector(class Connector *);
 	class ModelPart * modelPart();
 	const QList<Connector *> & connectors() const;
+	Connector * subConnector() const;
+    void addSubConnector(Connector *);
 	
 protected:
-
 	QList<class Connector *> m_connectors;
+	class Connector * m_subConnector;
 	BusShared * m_busShared;
 	QPointer<class ModelPart> m_modelPart;
 };
