@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6409 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
+$Revision: 6912 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-03-09 08:18:59 +0100 (Sa, 09. Mrz 2013) $
 
 ********************************************************************/
 
@@ -31,26 +31,47 @@ $Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 #include "../viewlayer.h"
 
-struct SvgIdLayer 
+
+struct PointRect {
+    QRectF rect;		
+	QPointF point;	
+	bool processed;
+	bool svgVisible;
+};
+
+class SvgIdLayer 
 {
+public:
+	SvgIdLayer(ViewLayer::ViewID);
+	SvgIdLayer * copyLayer();
+
+    QPointF point(ViewLayer::ViewLayerPlacement);
+    QRectF rect(ViewLayer::ViewLayerPlacement);
+    bool processed(ViewLayer::ViewLayerPlacement);
+    bool svgVisible(ViewLayer::ViewLayerPlacement);
+    void unprocess();
+    void setInvisible(ViewLayer::ViewLayerPlacement);
+    void setPointRect(ViewLayer::ViewLayerPlacement, QPointF, QRectF, bool svgVisible);
+
+public:
 	QString m_svgId;
 	QString m_terminalId;
-    ViewLayer::ViewIdentifier m_viewIdentifier;
+    ViewLayer::ViewID m_viewID;
 	ViewLayer::ViewLayerID m_svgViewLayerID;
-	bool m_svgVisible;
 	bool m_hybrid;
-	bool m_processed;
-	QRectF m_rect;		
-	QPointF m_point;	
 	double m_radius;
 	double m_strokeWidth;
 	QString m_legId;
 	QString m_legColor;
 	double m_legStrokeWidth;
 	QLineF m_legLine;
+    bool m_path;
 
-	SvgIdLayer(ViewLayer::ViewIdentifier);
-	SvgIdLayer * copyLayer();
+protected:
+    PointRect m_pointRectBottom;
+    PointRect m_pointRectTop;
+
+protected:
 };
 
 
