@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 $Revision: 6112 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Date: 2012-06-28 00:18:10 +0200 (Do, 28. Jun 2012) $
 
 ********************************************************************/
 
@@ -141,8 +141,9 @@ void GroundFillSeedDialog::showEqualPotential(ConnectorItem * connectorItem, boo
 		QList<ConnectorItem *> connectorItems;
 		connectorItems.append(connectorItem);
 		ConnectorItem::collectEqualPotential(connectorItems, true, ViewGeometry::NoFlag);
+	    QList<ConnectorItem *> visited;
 		foreach (ConnectorItem * ci, connectorItems) {
-			ci->showEqualPotential(show);
+			ci->showEqualPotential(show, visited);
 		}
 	}
 }
