@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5730 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-01-05 20:17:05 +0100 (Thu, 05 Jan 2012) $
+$Revision: 6732 $:
+$Author: irascibl@gmail.com $:
+$Date: 2012-12-27 08:26:48 +0100 (Do, 27. Dez 2012) $
 
 ********************************************************************/
 
@@ -36,20 +36,14 @@ $Date: 2012-01-05 20:17:05 +0100 (Thu, 05 Jan 2012) $
 #include <QRadioButton>
 #include <QLineEdit>
 #include <QDoubleValidator>
+#include <QPointer>
 
 
 struct ViewInfoThing
 {
-	QLineEdit * lineEdit;
-	QDoubleValidator * validator;
-	QRadioButton * mmButton;
-	QRadioButton * inButton;
-	double defaultGridSize;
 	QString viewName;
 	QString shortName;
 	int index;
-	QColor currentBColor;
-	QColor standardBColor;
 	bool curvy;
 };
 
@@ -66,7 +60,7 @@ public:
 	QHash<QString, QString> & settings();
 	QHash<QString, QString> & tempSettings();
 	void initLayout(QFileInfoList & list);
-	void initViewInfo(int index, const QString & viewName, const QString & shortName, double defaultSize, QColor current, QColor standard, bool curvy);
+	void initViewInfo(int index, const QString & viewName, const QString & shortName, bool curvy);
 
 protected:
 	QWidget * createLanguageForm(QFileInfoList & list);
@@ -79,9 +73,6 @@ protected:
 	void initBreadboard(QWidget *, ViewInfoThing *);
 	void initSchematic(QWidget *, ViewInfoThing *);
 	void initPCB(QWidget *, ViewInfoThing *);
-	QWidget * createGridSizeForm(ViewInfoThing *);
-	QWidget * createBackgroundColorForm(ViewInfoThing *);
-	void updateGridSize(ViewInfoThing *);
 	QWidget * createCurvyForm(ViewInfoThing *);
 
 protected slots:
@@ -92,19 +83,15 @@ protected slots:
 	void changeWheelBehavior();
 	void toggleAutosave(bool);
 	void changeAutosavePeriod(int);
-	void units(bool);
-	void restoreDefault();
-	void setBackgroundColor();
-	void gridEditingFinished();
 	void curvyChanged();
 
 protected:
-	QTabWidget * m_tabWidget;
-	QWidget * m_general;
-	QWidget * m_breadboard;
-	QWidget * m_schematic;
-	QWidget * m_pcb;
-	QLabel * m_wheelLabel;
+	QPointer<QTabWidget> m_tabWidget;
+	QPointer<QWidget> m_general;
+	QPointer<QWidget> m_breadboard;
+	QPointer<QWidget> m_schematic;
+	QPointer<QWidget> m_pcb;
+	QPointer<QLabel> m_wheelLabel[3];
 	QHash<QString, QString> m_settings;
 	QHash<QString, QString> m_tempSettings;
 	QString m_name;
