@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2014 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -31,17 +31,16 @@ $Date: 2013-04-19 12:51:22 +0200 (Fr, 19. Apr 2013) $
 #include "fsplashscreen.h"
 #include "version/version.h"
 #include "dialogs/prefsdialog.h"
-#include "help/helper.h"
 #include "fsvgrenderer.h"
 #include "version/versionchecker.h"
 #include "version/updatedialog.h"
 #include "itemdrag.h"
-#include "dock/viewswitcher.h"
 #include "items/wire.h"
 #include "partsbinpalette/binmanager/binmanager.h"
 #include "help/tipsandtricks.h"
 #include "utils/folderutils.h"
 #include "utils/lockmanager.h"
+#include "utils/fmessagebox.h"
 #include "dialogs/translatorlistmodel.h"
 #include "partsbinpalette/partsbinview.h"
 #include "partsbinpalette/svgiconwidget.h"
@@ -66,6 +65,8 @@ $Date: 2013-04-19 12:51:22 +0200 (Fr, 19. Apr 2013) $
 #include "autoroute/panelizer.h"
 #include "sketch/sketchwidget.h"
 #include "sketch/pcbsketchwidget.h"
+#include "help/firsttimehelpdialog.h"
+#include "help/aboutbox.h"
 
 // dependency injection :P
 #include "referencemodel/sqlitereferencemodel.h"
@@ -92,18 +93,22 @@ $Date: 2013-04-19 12:51:22 +0200 (Fr, 19. Apr 2013) $
 #ifdef LINUX_64
 #define PLATFORM_NAME "linux-64bit"
 #endif
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
+#ifdef WIN64
+#define PLATFORM_NAME "windows-64bit"
+#else
 #define PLATFORM_NAME "windows"
 #endif
-#ifdef Q_WS_MAC
-#ifdef QT_MAC_USE_COCOA
+#endif
+#ifdef Q_OS_MAC
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)) || defined(QT_MAC_USE_COCOA)
 #define PLATFORM_NAME "mac-os-x-105"
 #else
 #define PLATFORM_NAME "mac-os-x-104"
 #endif
 #endif
 
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
 #ifndef QT_NO_DEBUG
 #define WIN_DEBUG
 #endif
@@ -348,12 +353,12 @@ bool FApplication::init() {
 			toRemove << i << i + 1;
 		}
 
-		if ((m_arguments[i].compare("-drc", Qt::CaseInsensitive) == 0) ||
-			(m_arguments[i].compare("--drc", Qt::CaseInsensitive) == 0)) {
-			m_serviceType = DRCService;
-			m_outputFolder = m_arguments[i + 1];
-			toRemove << i << i + 1;
-		}
+		//if ((m_arguments[i].compare("-drc", Qt::CaseInsensitive) == 0) ||
+		//	(m_arguments[i].compare("--drc", Qt::CaseInsensitive) == 0)) {
+		//	m_serviceType = DRCService;
+		//	m_outputFolder = m_arguments[i + 1];
+		//	toRemove << i << i + 1;
+		//}
 
 		if ((m_arguments[i].compare("-db", Qt::CaseInsensitive) == 0) ||
             (m_arguments[i].compare("-database", Qt::CaseInsensitive) == 0) ||
@@ -508,13 +513,23 @@ bool FApplication::init() {
 	ItemBase::initNames();
 	ViewLayer::initNames();
 	Connector::initNames();
-	Helper::initText();
 	BinManager::initNames();
 	PaletteModel::initNames();
 	SvgIconWidget::initNames();
 	PinHeader::initNames();
 	CursorMaster::initCursors();
 
+#ifdef Q_OS_MAC
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)) || defined(QT_MAC_USE_COCOA)
+	m_buildType = " Cocoa";
+#else
+	m_buildType = " Carbon";
+#endif
+#else
+    m_buildType = QString(PLATFORM_NAME).contains("64") ? "64" : "32";
+#endif
+    AboutBox::initBuildType(m_buildType);
+
 	return true;
 }
 
@@ -534,10 +549,10 @@ FApplication::~FApplication(void)
 	ItemBase::cleanup();
 	Wire::cleanup();
 	DebugDialog::cleanup();
-	ViewSwitcher::cleanup();
 	ItemDrag::cleanup();
 	Version::cleanup();
 	TipsAndTricks::cleanup();
+	FirstTimeHelpDialog::cleanup();
 	TranslatorListModel::cleanup();
 	FolderUtils::cleanup();
 	SearchLineEdit::cleanup();
@@ -668,13 +683,18 @@ void FApplication::registerFonts() {
 	registerFont(":/resources/fonts/DroidSansMono.ttf", false);
 	registerFont(":/resources/fonts/OCRA.ttf", true);
 
-	/*	
+    // "Droid Sans" 
+    // "Droid Sans Mono" 
+		
+    /*
 		QFontDatabase database;
 		QStringList families = database.families (  );
 		foreach (QString string, families) {
 			DebugDialog::debug(string);			// should print out the name of the fonts you loaded
 		}
-	*/	
+*/
+
+
 }
 
 ReferenceModel * FApplication::loadReferenceModel(const QString & databaseName, bool fullLoad) {
@@ -707,11 +727,12 @@ ReferenceModel * FApplication::loadReferenceModel(const QString & databaseName,
 	return m_referenceModel;
 }
 
-MainWindow * FApplication::openWindowForService(bool lockFiles) {
+MainWindow * FApplication::openWindowForService(bool lockFiles, int initialTab) {
 	// our MainWindows use WA_DeleteOnClose so this has to be added to the heap (via new) rather than the stack (for local vars)
-	MainWindow * mainWindow = MainWindow::newMainWindow(m_referenceModel, "", false, lockFiles);   // this is also slow
+	MainWindow * mainWindow = MainWindow::newMainWindow(m_referenceModel, "", false, lockFiles, initialTab);   // this is also slow
 	mainWindow->setReportMissingModules(false);
     mainWindow->noBackup();
+    mainWindow->noSchematicConversion();
 
 	return mainWindow;
 }
@@ -723,6 +744,17 @@ int FApplication::serviceStartup() {
 	}
 
 	switch (m_serviceType) {
+        case PortService:
+            initService();
+            {
+                MainWindow * sketch = MainWindow::newMainWindow(m_referenceModel, "", true, true, -1);
+                if (sketch) {
+                    sketch->show();
+                    sketch->clearFileProgressDialog();
+                }
+            }
+            return 1;
+
 		case GedaService:
 			runGedaService();
 			return 0;
@@ -784,11 +816,11 @@ void FApplication::runGerberServiceAux()
 	QStringList filenames = dir.entryList(filters, QDir::Files);
 	foreach (QString filename, filenames) {
 		QString filepath = dir.absoluteFilePath(filename);
-		MainWindow * mainWindow = openWindowForService(false);
+		MainWindow * mainWindow = openWindowForService(false, 3);
 		m_started = true;
         
 		FolderUtils::setOpenSaveFolderAux(m_outputFolder);
-		if (mainWindow->loadWhich(filepath, false, false, "")) {
+		if (mainWindow->loadWhich(filepath, false, false, false, "")) {
             QFileInfo info(filepath);
             GerberGenerator::exportToGerber(info.completeBaseName(), m_outputFolder, NULL, mainWindow->pcbView(), false);
 		}
@@ -807,7 +839,7 @@ void FApplication::initService()
 
 void FApplication::runSvgService()
 {
-    initService();
+
     runSvgServiceAux();
 }
 
@@ -820,11 +852,11 @@ void FApplication::runSvgServiceAux()
 	QStringList filenames = dir.entryList(filters, QDir::Files);
 	foreach (QString filename, filenames) {
 		QString filepath = dir.absoluteFilePath(filename);
-		MainWindow * mainWindow = openWindowForService(false);
+		MainWindow * mainWindow = openWindowForService(false, -1);
 		m_started = true;
         
 		FolderUtils::setOpenSaveFolderAux(m_outputFolder);
-		if (mainWindow->loadWhich(filepath, false, false, "")) {
+		if (mainWindow->loadWhich(filepath, false, false, false, "")) {
             QFileInfo info(filepath);
             QList<ViewLayer::ViewID> ids;
             ids << ViewLayer::BreadboardView << ViewLayer::SchematicView << ViewLayer::PCBView;
@@ -906,12 +938,12 @@ void FApplication::runDRCService() {
 		QStringList filenames = dir.entryList(filters, QDir::Files);
 		foreach (QString filename, filenames) {
 			QString filepath = dir.absoluteFilePath(filename);
-	        MainWindow * mainWindow = openWindowForService(false);
+	        MainWindow * mainWindow = openWindowForService(false, 3);
             if (mainWindow == NULL) continue;
 
             mainWindow->setCloseSilently(true);
 
-	        if (!mainWindow->loadWhich(filepath, false, false, "")) {
+	        if (!mainWindow->loadWhich(filepath, false, false, false, "")) {
 		        DebugDialog::debug(QString("failed to load '%1'").arg(filepath));
 		        mainWindow->close();
                 delete mainWindow;
@@ -1055,7 +1087,7 @@ int FApplication::startup()
 	if (m_progressIndex >= 0) splash.showProgress(m_progressIndex, LoadProgressStart);
 	ProcessEventBlocker::processEvents();
 
-	#ifdef Q_WS_WIN
+	#ifdef Q_OS_WIN
 		// associate .fz file with fritzing app on windows (xp only--vista is different)
 		// TODO: don't change settings if they're already set?
 		// TODO: only do this at install time?
@@ -1140,7 +1172,7 @@ void FApplication::registerFont(const QString &fontFile, bool reallyRegister) {
 		foreach (QString family, familyNames) {
 			InstalledFonts::InstalledFontsNameMapper.insert(family, finfo.completeBaseName());
 			InstalledFonts::InstalledFontsList << family;
-			//DebugDialog::debug("registering font family: "+family);
+			DebugDialog::debug(QString("registering font family: %1 %2").arg(family).arg(finfo.completeBaseName()));
 		}
 	}
 }
@@ -1153,8 +1185,8 @@ void FApplication::finish()
 }
 
 void FApplication::loadNew(QString path) {
-	MainWindow * mw = MainWindow::newMainWindow(m_referenceModel, path, true, true);
-	if (!mw->loadWhich(path, false, true, "")) {
+	MainWindow * mw = MainWindow::newMainWindow(m_referenceModel, path, true, true, -1);
+	if (!mw->loadWhich(path, false, true, true, "")) {
 		mw->close();
 	}
 	mw->clearFileProgressDialog();
@@ -1163,7 +1195,7 @@ void FApplication::loadNew(QString path) {
 void FApplication::loadOne(MainWindow * mw, QString path, int loaded) {
 	if (loaded == 0) {
 		mw->showFileProgressDialog(path);
-		mw->loadWhich(path, true, true, "");
+		mw->loadWhich(path, true, true, true, "");
 	}
 	else {
 		loadNew(path);
@@ -1274,23 +1306,15 @@ void FApplication::initSplash(FSplashScreen & splash) {
 							.arg(Version::year());
 	splash.showMessage(msg1, "fhpText", Qt::AlignLeft | Qt::AlignTop);
 
-	QString macBuildType;
-#ifdef Q_WS_MAC
-#ifdef QT_MAC_USE_COCOA
-	macBuildType = " Cocoa";
-#else
-	macBuildType = " Carbon";
-#endif
-#endif
 	QString msg2 = QObject::tr("<font face='Lucida Grande, Tahoma, Sans Serif' size='2' color='#eaf4ed'>"
-							   "Version %1.%2.%3 (%4%5)%6"
+							   "Version %1.%2.%3 (%4%5) %6"
 							   "</font>")
 						.arg(Version::majorVersion())
 						.arg(Version::minorVersion())
 						.arg(Version::minorSubVersion())
 						.arg(Version::modifier())
 						.arg(Version::shortDate())
-						.arg(macBuildType);
+						.arg(m_buildType);
 	splash.showMessage(msg2, "versionText", Qt::AlignRight | Qt::AlignTop);
     splash.show();
 }
@@ -1302,7 +1326,6 @@ struct Thing {
 };
 
 
-
 void FApplication::checkForUpdates() {
 	checkForUpdates(true);
 }
@@ -1487,8 +1510,9 @@ which is really not intended for hundreds of widgets.
 
 bool FApplication::runAsService() {
     if (m_serviceType == PortService) {
+        DebugDialog::setEnabled(true);
         initServer();
-        return false;
+        //return false;
     }
 
 	return m_serviceType != NoService;
@@ -1515,11 +1539,16 @@ bool FApplication::notify(QObject *receiver, QEvent *e)
         return QApplication::notify(receiver, e);
     }
 	catch (char const *str) {
-        QMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception %1 from %2 in event %3")
+        FMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception %1 from %2 in event %3")
 			.arg(str).arg(receiver->objectName()).arg(e->type()));
 	}
+    catch (std::exception& exp) {
+        // suggested in https://code.google.com/p/fritzing/issues/detail?id=2698
+        qDebug() << QString("notify %1 %2").arg(receiver->metaObject()->className()).arg(e->type());
+        FMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception from %1 in event %2: %3").arg(receiver->objectName()).arg(e->type()).arg(exp.what()));
+    }
     catch (...) {
-        QMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception from %1 in event %2").arg(receiver->objectName()).arg(e->type()));
+        FMessageBox::critical(NULL, tr("Fritzing failure"), tr("Fritzing caught an exception from %1 in event %2").arg(receiver->objectName()).arg(e->type()));
     }
 	closeAllWindows2();
 	QApplication::exit(-1);
@@ -1557,8 +1586,8 @@ void FApplication::loadSomething(const QString & prevVersion) {
 
         foreach (QString filename, m_filesToLoad) {
             DebugDialog::debug(QString("Loading non-service file %1").arg(filename));
-            MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, filename, true, true);
-            mainWindow->loadWhich(filename, true, true, "");
+            MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, filename, true, true, -1);
+            mainWindow->loadWhich(filename, true, true, true, "");
             if (filename.endsWith(FritzingSketchExtension) || filename.endsWith(FritzingBundleExtension)) {
             }
             else {
@@ -1571,13 +1600,14 @@ void FApplication::loadSomething(const QString & prevVersion) {
     // Find any previously open sketches to reload
     if (!loadPrevious && sketchesToLoad.isEmpty()) {
 		DebugDialog::debug(QString("load last open"));
-		sketchesToLoad = loadLastOpenSketch();
+        // new logic here, we no longer open the most recent sketch, since it can be reached in one click from the welcome page
+		//sketchesToLoad = loadLastOpenSketch();
 	}
 
 	MainWindow * newBlankSketch = NULL;
 	if (sketchesToLoad.isEmpty()) {
 		DebugDialog::debug(QString("create empty sketch"));
-		newBlankSketch = MainWindow::newMainWindow(m_referenceModel, "", true, true);
+		newBlankSketch = MainWindow::newMainWindow(m_referenceModel, "", true, true, -1);
 		if (newBlankSketch) {
 			// make sure to start an empty sketch with a board
 			newBlankSketch->addDefaultParts();   // do this before call to show()
@@ -1598,6 +1628,8 @@ void FApplication::loadSomething(const QString & prevVersion) {
 	}
 	else if (newBlankSketch) {
 		newBlankSketch->hideTempPartsBin();
+        // new empty sketch defaults to welcome view
+        newBlankSketch->showWelcomeView();
 	}
 }
 
@@ -1614,8 +1646,8 @@ QList<MainWindow *> FApplication::loadLastOpenSketch() {
 
     DebugDialog::debug(QString("Loading last open sketch %1").arg(lastSketchPath));
     settings.remove("lastOpenSketch");				// clear the preference, in case the load crashes
-    MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, lastSketchPath, true, true);
-    mainWindow->loadWhich(lastSketchPath, true, true, "");
+    MainWindow *mainWindow = MainWindow::newMainWindow(m_referenceModel, lastSketchPath, true, true, -1);
+    mainWindow->loadWhich(lastSketchPath, true, true, true, "");
     sketches << mainWindow;
     settings.setValue("lastOpenSketch", lastSketchPath);	// the load works, so restore the preference
 	return sketches;
@@ -1626,7 +1658,7 @@ void FApplication::doLoadPrevious(MainWindow * sketchWindow) {
     // This should be done before any files are loaded as it requires a restart.
     // As this can generate UI it should come after the splash screen has closed.
 
-    QMessageBox messageBox(sketchWindow);
+    FMessageBox messageBox(sketchWindow);
     messageBox.setWindowTitle(tr("Import files from previous version?"));
     messageBox.setText(tr("Do you want to import parts and bins that you have created with earlier versions of Fritzing?\n"));
     messageBox.setInformativeText(tr("\nNote: You can import them later using the \"Help\" > \"Import parts and bins "
@@ -1672,11 +1704,10 @@ QList<MainWindow *> FApplication::recoverBackups()
 			QString fileExt;
 			QString bundledFileName = FolderUtils::getSaveFileName(NULL, tr("Please specify an .fzz file name to save to (cancel will delete the backup)"), originalPath, tr("Fritzing (*%1)").arg(FritzingBundleExtension), &fileExt);
 			if (!bundledFileName.isEmpty()) {
-				MainWindow *currentRecoveredSketch = MainWindow::newMainWindow(m_referenceModel, originalBaseName, true, true);
-    			currentRecoveredSketch->mainLoad(backupName, bundledFileName);
+				MainWindow *currentRecoveredSketch = MainWindow::newMainWindow(m_referenceModel, originalBaseName, true, true, -1);
+    			currentRecoveredSketch->mainLoad(backupName, bundledFileName, true);
 				currentRecoveredSketch->saveAsShareable(bundledFileName, true);
 				currentRecoveredSketch->setCurrentFile(bundledFileName, true, true);
-				currentRecoveredSketch->showAllFirstTimeHelp(false);
 				recoveredSketches << currentRecoveredSketch;
 
 				/*
@@ -1740,12 +1771,16 @@ void FApplication::runInscriptionService()
 {	
 	m_started = true;
     bool drc = false;
+    bool noMessages = false;
     foreach (QString arg, m_arguments) {
         if (arg.compare("-drc", Qt::CaseInsensitive) == 0) {
             drc = true;
         }
+        if (arg.compare("-nm", Qt::CaseInsensitive) == 0) {
+            noMessages = true;
+        }
     }
-	Panelizer::inscribe(this, m_panelFilename, drc);
+	Panelizer::inscribe(this, m_panelFilename, drc, noMessages);
 }
 
 QList<MainWindow *> FApplication::orderedTopLevelMainWindows() {
@@ -1775,17 +1810,19 @@ void FApplication::runExampleService(QDir & dir) {
 		QString path = fileInfo.absoluteFilePath();
 		DebugDialog::debug("sketch file " + path);
 
-		MainWindow * mainWindow = openWindowForService(false);
+		MainWindow * mainWindow = openWindowForService(false, -1);
 		if (mainWindow == NULL) continue;
 
 		FolderUtils::setOpenSaveFolderAux(dir.absolutePath());
 
-		if (!mainWindow->loadWhich(path, false, false, "")) {
+		if (!mainWindow->loadWhich(path, false, false, true, "")) {
 			DebugDialog::debug(QString("failed to load"));
 		}
 		else {
-			mainWindow->selectAllObsolete(false);
-			mainWindow->swapObsolete(false);
+			QList<ItemBase *> items = mainWindow->selectAllObsolete(false);
+			if (items.count() > 0) {
+                mainWindow->swapObsolete(false, items);
+            }
 			mainWindow->saveAsAux(path);    //   path + "z"
 			mainWindow->setCloseSilently(true);
 			mainWindow->close();
@@ -1809,6 +1846,7 @@ void FApplication::cleanFzzs() {
 }
 
 void FApplication::initServer() {
+    FMessageBox::BlockMessages = true;
     m_fServer = new FServer(this);
     connect(m_fServer, SIGNAL(newConnection(int)), this, SLOT(newConnection(int)));
     m_fServer->listen(QHostAddress::Any, m_portNumber);
