@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6505 $:
+$Revision: 6998 $:
 $Author: irascibl@gmail.com $:
-$Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
+$Date: 2013-04-28 13:51:10 +0200 (So, 28. Apr 2013) $
 
 ********************************************************************/
 
@@ -32,6 +32,7 @@ $Date: 2012-10-03 10:14:52 +0200 (Wed, 03 Oct 2012) $
 #include "../svg/svgfilesplitter.h"
 #include "../sketch/infographicsview.h"
 #include "../debugdialog.h"
+#include "../layerattributes.h"
 
 static QString Copper0LayerTemplate = "";
 static QString JumperWireLayerTemplate = "";
@@ -69,10 +70,11 @@ void shorten(QRectF r0, QPointF r0c, QPointF r1c, double & r0x, double & r0y, do
 
 /////////////////////////////////////////////////////////
 
-JumperItem::JumperItem( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
-	: PaletteItem(modelPart, viewIdentifier,  viewGeometry,  id, itemMenu, doLabel)
+JumperItem::JumperItem( ModelPart * modelPart, ViewLayer::ViewID viewID,  const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel) 
+	: PaletteItem(modelPart, viewID,  viewGeometry,  id, itemMenu, doLabel)
 {
-	if (Colors.isEmpty()) {
+    m_originalClickItem = NULL;
+    if (Colors.isEmpty()) {
 		Colors.insert(ViewLayer::Copper0, ViewLayer::Copper0Color);
 		Colors.insert(ViewLayer::Copper1, ViewLayer::Copper1Color);
 		Colors.insert(ViewLayer::PartImage, JumperColor);
@@ -101,7 +103,7 @@ JumperItem::~JumperItem() {
 
 QRectF JumperItem::boundingRect() const
 {
-    if (m_viewIdentifier != ViewLayer::PCBView) {
+    if (m_viewID != ViewLayer::PCBView) {
         return PaletteItem::boundingRect();
     }
 
@@ -110,7 +112,7 @@ QRectF JumperItem::boundingRect() const
 
 void JumperItem::paintHover(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-    if (m_viewIdentifier != ViewLayer::PCBView) {
+    if (m_viewID != ViewLayer::PCBView) {
        PaletteItem::paintHover(painter, option, widget);
 	   return;
     }
@@ -120,7 +122,7 @@ void JumperItem::paintHover(QPainter *painter, const QStyleOptionGraphicsItem *o
 
 void JumperItem::paintSelected(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-    if (m_viewIdentifier != ViewLayer::PCBView) {
+    if (m_viewID != ViewLayer::PCBView) {
        PaletteItem::paintSelected(painter, option, widget);
 	   return;
     }
@@ -130,7 +132,7 @@ void JumperItem::paintSelected(QPainter *painter, const QStyleOptionGraphicsItem
 
 QPainterPath JumperItem::hoverShape() const
 {
-    if (m_viewIdentifier != ViewLayer::PCBView) {
+    if (m_viewID != ViewLayer::PCBView) {
         return PaletteItem::hoverShape();
      }
 
@@ -155,11 +157,11 @@ QPainterPath JumperItem::shape() const
 	return hoverShape();
 }
 
-bool JumperItem::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const LayerHash & viewLayers, ViewLayer::ViewLayerID viewLayerID, ViewLayer::ViewLayerSpec viewLayerSpec, bool doConnectors, LayerAttributes & layerAttributes, QString & error)
+bool JumperItem::setUpImage(ModelPart * modelPart, const LayerHash & viewLayers, LayerAttributes & layerAttributes)
 {
-	bool result = PaletteItem::setUpImage(modelPart, viewIdentifier, viewLayers, viewLayerID, viewLayerSpec, doConnectors, layerAttributes, error);
+	bool result = PaletteItem::setUpImage(modelPart, viewLayers, layerAttributes);
 
-	if (doConnectors) {
+	if (layerAttributes.doConnectors) {
 		foreach (ConnectorItem * item, cachedConnectorItems()) {
 			item->setCircular(true);
 			if (item->connectorSharedName().contains('0')) {
@@ -172,14 +174,14 @@ bool JumperItem::setUpImage(ModelPart * modelPart, ViewLayer::ViewIdentifier vie
 			}
 		}
 
-		initialResize(viewIdentifier);
+		initialResize(layerAttributes.viewID);
 	}
 
 	return result;
 }
 
-void JumperItem::initialResize(ViewLayer::ViewIdentifier viewIdentifier) {
-	if (viewIdentifier != ViewLayer::PCBView) return;
+void JumperItem::initialResize(ViewLayer::ViewID viewID) {
+	if (viewID != ViewLayer::PCBView) return;
 
 	bool ok;
 	double r0x = m_modelPart->localProp("r0x").toDouble(&ok);
@@ -201,8 +203,29 @@ void JumperItem::initialResize(ViewLayer::ViewIdentifier viewIdentifier) {
 
 }
 
+bool JumperItem::mousePressEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *event)
+{
+    m_originalClickItem = originalItem;
+    mousePressEvent(event);
+    return (m_dragItem != NULL);
+}
+
+void JumperItem::mouseMoveEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *event)
+{
+    Q_UNUSED(originalItem);
+    mouseMoveEvent(event);
+}
+
+void JumperItem::mouseReleaseEvent(PaletteItemBase * originalItem, QGraphicsSceneMouseEvent *event)
+{
+    Q_UNUSED(originalItem);
+    mouseReleaseEvent(event);
+}
+
 void JumperItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
+    PaletteItemBase * originalItem = m_originalClickItem;
+    m_originalClickItem = NULL;
 	InfoGraphicsView *infographics = InfoGraphicsView::getInfoGraphicsView(this);
 	if (infographics != NULL && infographics->spaceBarIsPressed()) { 
 		event->ignore();
@@ -228,6 +251,7 @@ void JumperItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 			m_otherItem = m_connector0;
 		}
 		else {
+            if (originalItem) return ItemBase::mousePressEvent(event);
 			return PaletteItem::mousePressEvent(event);
 		}
 	}
@@ -265,7 +289,8 @@ void JumperItem::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 	if (cross) cross->setRect(r);
 
 	resize();
-	ItemBase::updateConnections(m_dragItem);	
+    QList<ConnectorItem *> already;
+	ItemBase::updateConnections(m_dragItem, true, already);	
 }
 
 void JumperItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
@@ -336,7 +361,7 @@ void JumperItem::resize(QPointF p0, QPointF p1) {
 }
 
 void JumperItem::resize() {
-	if (m_viewIdentifier != ViewLayer::PCBView) return;
+	if (m_viewID != ViewLayer::PCBView) return;
 
 	if (m_connector0 == NULL) return;
 	if (m_connector1 == NULL) return;
@@ -412,7 +437,7 @@ QSizeF JumperItem::footprintSize() {
 	return r0.size();
 }
 
-QString JumperItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi) 
+QString JumperItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor) 
 {
 	QString xml = "";
 	switch (viewLayerID) {
@@ -427,10 +452,10 @@ QString JumperItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QStrin
 	}
 
 	if (!xml.isEmpty()) {
-        return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi);
+        return PaletteItemBase::normalizeSvg(xml, viewLayerID, blackOnly, dpi, factor);
 	}
 
-	return PaletteItemBase::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi);
+	return PaletteItemBase::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi, factor);
 }
 
 void JumperItem::setAutoroutable(bool ar) {
@@ -450,7 +475,7 @@ ConnectorItem * JumperItem::connector1() {
 }
 
 bool JumperItem::hasCustomSVG() {
-	switch (m_viewIdentifier) {
+	switch (m_viewID) {
 		case ViewLayer::PCBView:
 			return true;
 		default:
@@ -462,8 +487,8 @@ bool JumperItem::inDrag() {
 	return m_dragItem != NULL;
 }
 
-void JumperItem::loadLayerKin( const LayerHash & viewLayers, ViewLayer::ViewLayerSpec viewLayerSpec) {
-	PaletteItem::loadLayerKin(viewLayers, viewLayerSpec);
+void JumperItem::loadLayerKin( const LayerHash & viewLayers, ViewLayer::ViewLayerPlacement viewLayerPlacement) {
+	PaletteItem::loadLayerKin(viewLayers, viewLayerPlacement);
 	resize();
 }
 
@@ -488,7 +513,8 @@ void JumperItem::addedToScene(bool temporary) {
 	PaletteItem::addedToScene(temporary);
 }
 
-void JumperItem::rotateItem(double degrees) {
+void JumperItem::rotateItem(double degrees, bool updateRatsnest) {
+    Q_UNUSED(updateRatsnest);
 	QPointF tc0, tc1;
 	QTransform rotation;
 	rotation.rotate(degrees);
@@ -545,7 +571,7 @@ bool JumperItem::hasPartNumberProperty()
 	return false;
 }
 
-ViewLayer::ViewIdentifier JumperItem::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+ViewLayer::ViewID JumperItem::useViewIDForPixmap(ViewLayer::ViewID vid, bool) 
 {
     if (vid == ViewLayer::PCBView) {
         return ViewLayer::IconView;
