@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6409 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -43,11 +43,11 @@ class Pad : public ResizableBoard
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	Pad(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	Pad(ModelPart *, ViewLayer::ViewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~Pad();
 
-	QString retrieveSvg(ViewLayer::ViewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi);
-	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	QString retrieveSvg(ViewLayer::ViewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide);
 	bool canEditPart();
 	void setProp(const QString & prop, const QString & value);
 	bool hasPartLabel();
@@ -56,6 +56,7 @@ public:
 	bool rotationAllowed();
 	bool rotation45Allowed();
 	bool freeRotationAllowed(Qt::KeyboardModifiers);	
+	bool freeRotationAllowed();	
 	bool hasPartNumberProperty();
 	void setInitialSize();
 	void addedToScene(bool temporary);
@@ -69,12 +70,13 @@ protected slots:
 protected:
 	double minWidth();
 	double minHeight();
-	ViewLayer::ViewIdentifier theViewIdentifier();
+	ViewLayer::ViewID theViewID();
 	QString makeLayerSvg(ViewLayer::ViewLayerID viewLayerID, double mmW, double mmH, double milsW, double milsH);
 	QString makeFirstLayerSvg(double mmW, double mmH, double milsW, double milsH);
 	QString makeNextLayerSvg(ViewLayer::ViewLayerID, double mmW, double mmH, double milsW, double milsH);
 	void resizeMMAux(double w, double h);
 	ResizableBoard::Corner findCorner(QPointF, Qt::KeyboardModifiers);
+	QStringList collectValues(const QString & family, const QString & prop, QString & value);
 
 protected:
     bool m_copperBlocker;
@@ -86,7 +88,7 @@ class CopperBlocker : public Pad
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	CopperBlocker(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	CopperBlocker(ModelPart *, ViewLayer::ViewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~CopperBlocker();
 
     bool hasPartLabel();
