@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2014 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6409 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -29,7 +29,6 @@ $Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 #include "../fsvgrenderer.h"
 #include "../commands.h"
 #include "../utils/textutils.h"
-#include "../layerattributes.h"
 #include "partlabel.h"
 #include "partfactory.h"
 #include "../sketch/infographicsview.h"
@@ -45,6 +44,19 @@ $Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
 
 //////////////////////////////////////////////////
 
+QString doubleCopyPinFunction(int pin, const QString & argString, void *)
+{
+	return argString.arg(pin * 2).arg(pin * 2 + 1).arg(pin * 2 + 1).arg(pin * 2 + 2);
+}
+
+QString stdIncCopyPinFunction(int pin, const QString & argString, void *)
+{
+	return argString.arg(pin).arg(pin + 1);
+}
+
+//////////////////////////////////////////////////
+
+
 static QStringList Forms;
 
 QString PinHeader::FemaleFormString;
@@ -62,8 +74,8 @@ static QString ShroudedSpacing;
 
 static HoleClassThing TheHoleThing;
 
-PinHeader::PinHeader( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
-	: PaletteItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+PinHeader::PinHeader( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: PaletteItem(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
 {
 
     setUpHoleSizes("pinheader", TheHoleThing);
@@ -461,7 +473,7 @@ QString PinHeader::makePcbSvg(const QString & originalExpectedFileName)
 		svg = makePcbLongPadSvg(pins, expectedFileName.contains("alternating"));
 	}
 	else if (expectedFileName.contains("molex")) {
-		svg = makePcbMolexSvg(pins);
+		svg = makePcbMolexSvg(pins, spacingString);
 	}
     else {
 	    static QString pcbLayerTemplate = "";
@@ -593,11 +605,14 @@ void PinHeader::initSpacings() {
 	if (Spacings.count() == 0) {
 		ShroudedSpacing = "0.1in (2.54mm)";
 		Spacings.insert("1mm", "0.03937in (1.0mm)");
+		Spacings.insert("1.25mm", "0.04921in (1.25mm)");
 		Spacings.insert("50mil", "0.05in (1.27mm)");
 		Spacings.insert("1.5mm", "0.0591in (1.5mm)");
 		Spacings.insert("2mm", "0.07874in (2mm)");
-		Spacings.insert("2.5mm", "0.09843in (2.5mm)");
+		Spacings.insert("2.54mm", "0.09843in (2.54mm)");
 		Spacings.insert("100mil", ShroudedSpacing);
+		Spacings.insert("150mil", "0.15in (3.81mm)");
+        Spacings.insert("0.156in", "0.156in (3.96mm)");
 		Spacings.insert("200mil", "0.2in (5.08mm)");
 	}
 }
@@ -607,22 +622,51 @@ QString PinHeader::makeSchematicSvg(const QString & expectedFileName)
 	QStringList pieces = expectedFileName.split("_");
 	if (pieces.count() < 7) return "";
 
-	int pins = pieces.at(pieces.count() - 3).toInt();
+    bool useOldSchematic = expectedFileName.contains(PartFactory::OldSchematicPrefix);
+
+    QString spacingString;
+    int pins = TextUtils::getPinsAndSpacing(expectedFileName, spacingString);
 	QString form = expectedFileName.contains("female") ? "female" :"male";
-	double unitHeight = GraphicsUtils::StandardSchematicSeparationMils / 1000;  // inches
+    bool sizeTenth = expectedFileName.contains("10thin") || !useOldSchematic;  // some parts before version 0.8.5 used the 0.1 grid
+    bool isDouble = sizeTenth && expectedFileName.contains("double");
+
+    double width, unitHeight;
+    double divisor = isDouble ? 2 : 1;
+    if (sizeTenth) {
+        width = isDouble ? 0.5 : 0.2;
+        unitHeight = GraphicsUtils::StandardSchematicSeparation10thinMils / 1000;  // inches
+    }
+    else {
+        unitHeight = GraphicsUtils::StandardSchematicSeparationMils / 1000;  // inches
+        width = 0.87;
+    }
 	double unitHeightPoints = unitHeight * 72;
 
 	QString header("<?xml version='1.0' encoding='utf-8'?>\n"
 				"<svg version='1.2' baseProfile='tiny' id='svg2' xmlns:svg='http://www.w3.org/2000/svg' "
-				"xmlns='http://www.w3.org/2000/svg'  x='0in' y='0in' width='0.87in' "
-				"height='%1in' viewBox='0 0 62.641 %2'>\n"
+				"xmlns='http://www.w3.org/2000/svg'  x='0in' y='0in' width='%3in' "
+				"height='%1in' viewBox='0 0 %4 %2'>\n"
 				"<g id='schematic' >\n");
 
 
-	QString svg = header.arg(unitHeight * pins).arg(unitHeightPoints * pins);
+	QString svg = header.arg(unitHeight * pins / divisor).arg(unitHeightPoints * pins / divisor).arg(width).arg(width * 72);
 
-	svg += TextUtils::incrementTemplate(QString(":/resources/templates/generic_%1_pin_header_schem_template.txt").arg(form.contains("female") ? "female" : "male"),
-							 pins, unitHeightPoints, TextUtils::standardMultiplyPinFunction, TextUtils::standardCopyPinFunction, NULL);
+    QString templateFile = QString(":/resources/templates/generic_%1_%2%3pin_header_schem_template.txt")
+                                                .arg(form.contains("female") ? "female" : "male")
+                                                .arg(sizeTenth ? "10thin_" : "")
+                                                .arg(isDouble ? "double_" : "")
+                                                ;
+    if (sizeTenth) {
+        if (isDouble) {
+	        svg += TextUtils::incrementTemplate(templateFile, pins / 2, unitHeightPoints, TextUtils::standardMultiplyPinFunction, doubleCopyPinFunction, NULL);
+        }
+        else {
+	        svg += TextUtils::incrementTemplate(templateFile, pins, unitHeightPoints, TextUtils::standardMultiplyPinFunction, stdIncCopyPinFunction, NULL);
+        }
+    }
+    else {
+	    svg += TextUtils::incrementTemplate(templateFile, pins, unitHeightPoints, TextUtils::standardMultiplyPinFunction, TextUtils::standardCopyPinFunction, NULL);
+    }
 		
 
 	svg += "</g>\n</svg>";
@@ -914,11 +958,14 @@ QString PinHeader::makePcbLongPadLockSvg(int pins)
     return header.arg(totalHeight).arg(totalHeight * dpi).arg(repeats).arg(bottom).arg(betweens);
 }
 
-QString PinHeader::makePcbMolexSvg(int pins) 
+QString PinHeader::makePcbMolexSvg(int pins, const QString & spacingString) 
 {
     double dpi = 25.4;
     double originalHeight = 0.105;           // inches
     double increment = 0.1;                 // inches
+    bool ok;
+    double inc = TextUtils::convertToInches(spacingString, &ok, false);
+    if (ok) increment = inc;
 	QString header("<?xml version='1.0' encoding='utf-8'?>\n"
 					"<svg version='1.2' baseProfile='tiny' xmlns='http://www.w3.org/2000/svg' \n"
                     "x='0in' y='0in' width='0.225in' height='%1in' viewBox='0 0 5.715 %2'>\n"
@@ -1015,7 +1062,7 @@ QString PinHeader::makePcbSMDSvg(const QString & expectedFileName)
 	return svg;
 }
 
-bool PinHeader::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget) 
+bool PinHeader::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide) 
 {
 	if (prop.compare("hole size", Qt::CaseInsensitive) == 0) {
         if (moduleID().contains("smd", Qt::CaseInsensitive)) {
@@ -1027,7 +1074,7 @@ bool PinHeader::collectExtraInfo(QWidget * parent, const QString & family, const
         }
 	}
 
-	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget, hide);
 }
 
 void PinHeader::swapEntry(const QString & text) {
