@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2014 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6409 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-09-13 05:05:28 +0200 (Thu, 13 Sep 2012) $
+$Revision: 6984 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -40,14 +40,14 @@ class PinHeader : public PaletteItem
 
 public:
 	// after calling this constructor if you want to render the loaded svg (either from model or from file), MUST call <renderImage>
-	PinHeader(ModelPart *, ViewLayer::ViewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
+	PinHeader(ModelPart *, ViewLayer::ViewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel);
 	~PinHeader();
 
 	QString getProperty(const QString & key);
 	const QString & form();
 	PluralType isPlural();
 	void addedToScene(bool temporary);
-	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget);
+	bool collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide);
 
 protected:
 	QStringList collectValues(const QString & family, const QString & prop, QString & value);
@@ -71,7 +71,7 @@ public:
 	static QString makePcbShroudedSvg(int pins);
 	static QString makePcbLongPadSvg(int pins, bool lock);
 	static QString makePcbLongPadLockSvg(int pins);
-	static QString makePcbMolexSvg(int pins);
+	static QString makePcbMolexSvg(int pins, const QString & spacingString);
 	static QString makePcbSMDSvg(const QString & expectedFileName);
 	static QString makeSchematicSvg(const QString & expectedFileName);
 	static QString makeBreadboardSvg(const QString & expectedFileName);
