@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2014 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6508 $:
+$Revision: 6984 $:
 $Author: irascibl@gmail.com $:
-$Date: 2012-10-03 19:10:05 +0200 (Wed, 03 Oct 2012) $
+$Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -35,6 +35,9 @@ $Date: 2012-10-03 19:10:05 +0200 (Wed, 03 Oct 2012) $
 #include "../utils/graphicsutils.h"
 #include "../sketch/infographicsview.h"
 #include "partlabel.h"
+#include "partfactory.h"
+#include "layerkinpaletteitem.h"
+#include "../svg/svgfilesplitter.h"
 
 #include <QLineEdit>
 #include <QMultiHash>
@@ -77,8 +80,8 @@ void FocusBugLineEdit::editingFinishedSlot() {
 
 ////////////////////////////////////////
 
-SymbolPaletteItem::SymbolPaletteItem( ModelPart * modelPart, ViewLayer::ViewIdentifier viewIdentifier, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
-	: PaletteItem(modelPart, viewIdentifier, viewGeometry, id, itemMenu, doLabel)
+SymbolPaletteItem::SymbolPaletteItem( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: PaletteItem(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
 {
 	if (Voltages.count() == 0) {
 		Voltages.append(0.0);
@@ -92,28 +95,10 @@ SymbolPaletteItem::SymbolPaletteItem( ModelPart * modelPart, ViewLayer::ViewIden
 	m_voltageReference = (modelPart->properties().value("type").compare("voltage reference") == 0);
 
 	if (modelPart->moduleID().endsWith(ModuleIDNames::NetLabelModuleIDName)) {
-		m_isNetLabel = true;
-		QString label = getLabel();
-		if (label.isEmpty()) {
-			label = modelPart->properties().value("label");
-			if (label.isEmpty()) {
-				label = tr("net label");
-			}
-			modelPart->setLocalProp("label", label);
-		}
-        setInstanceTitle(label);
-
-		QString direction = getDirection();
-		if (direction.isEmpty()) {
-			direction = modelPart->properties().value("direction");
-			if (direction.isEmpty()) {
-				direction = "right";
-			}
-			modelPart->setLocalProp("direction", direction);
-		}
-	}
+	    m_isNetLabel = true;
+    }
 	else {
-		m_isNetLabel = false;
+		m_isNetLabel = modelPart->moduleID().endsWith(ModuleIDNames::PowerLabelModuleIDName);
 
 		bool ok;
 		double temp = modelPart->localProp("voltage").toDouble(&ok);
@@ -217,10 +202,10 @@ ConnectorItem* SymbolPaletteItem::newConnectorItem(Connector *connector)
 	return connectorItem;
 }
 
-void SymbolPaletteItem::busConnectorItems(Bus * bus, QList<class ConnectorItem *> & items) {
+void SymbolPaletteItem::busConnectorItems(Bus * bus, ConnectorItem * fromConnectorItem, QList<class ConnectorItem *> & items) {
 	if (bus == NULL) return;
 
-	PaletteItem::busConnectorItems(bus, items);
+	PaletteItem::busConnectorItems(bus, fromConnectorItem, items);
 
 	//foreach (ConnectorItem * bc, items) {
 		//bc->debugInfo(QString("bc %1").arg(bus->id()));
@@ -259,12 +244,6 @@ void SymbolPaletteItem::setProp(const QString & prop, const QString & value) {
 		setLabel(value);
 		return;
 	}
-	if (prop.compare("direction", Qt::CaseInsensitive) == 0 && m_isNetLabel) {
-		m_modelPart->setLocalProp("direction", value);
-	    QString svg = makeSvg();
-	    resetRenderer(svg);
-		return;
-	}
 
 	PaletteItem::setProp(prop, value);
 }
@@ -278,9 +257,14 @@ void SymbolPaletteItem::setLabel(const QString & label) {
 		LocalNetLabels.insert(label, connectorItem);
 	}
 
-	QString svg = makeSvg();
+    QTransform  transform = untransform();
+
+	QString svg = makeSvg(this->viewLayerID());
 	resetRenderer(svg);
+    resetLayerKin();
     resetConnectors(NULL, NULL);
+
+    retransform(transform);
 }
 
 void SymbolPaletteItem::setVoltage(double v) {
@@ -292,38 +276,55 @@ void SymbolPaletteItem::setVoltage(double v) {
 		Voltages.append(v);
 	}
 
-	foreach (ConnectorItem * connectorItem, cachedConnectorItems()) {
-		if (connectorItem->isGrounded()) {
-			LocalGrounds.append(connectorItem);
-			//connectorItem->debugInfo("ground insert");
-
-		}
-		else {
-			LocalVoltages.insert(FROMVOLTAGE(v), connectorItem);
-			//connectorItem->debugInfo(QString("voltage insert %1").arg(useVoltage(connectorItem)));
-		}
-	}
-
-	if (!m_voltageReference && !m_isNetLabel) return;
-
-	QString svg = makeSvg();
-	reloadRenderer(svg, false);
-
-    if (m_partLabel) m_partLabel->displayTextsIf();
-}
-
-QString SymbolPaletteItem::makeSvg() {
     if (m_isNetLabel) {
-        return makeNetLabelSvg();
+	    foreach (ConnectorItem * connectorItem, cachedConnectorItems()) {
+		    LocalNetLabels.insert(QString::number(m_voltage), connectorItem);
+	    }
+    }
+    else {
+	    foreach (ConnectorItem * connectorItem, cachedConnectorItems()) {
+		    if (connectorItem->isGrounded()) {
+			    LocalGrounds.append(connectorItem);
+			    //connectorItem->debugInfo("ground insert");
+
+		    }
+		    else {
+			    LocalVoltages.insert(FROMVOLTAGE(v), connectorItem);
+			    //connectorItem->debugInfo(QString("voltage insert %1").arg(useVoltage(connectorItem)));
+		    }
+	    }
     }
 
+    if (m_viewID == ViewLayer::SchematicView) {
+        if (m_voltageReference || m_isNetLabel) {
+            QTransform transform = untransform();
+	        QString svg = makeSvg(viewLayerID());
+	        reloadRenderer(svg, false);
+
+            resetLayerKin();
+
+            retransform(transform);
+
+            if (m_partLabel) m_partLabel->displayTextsIf();
+        }
+    }
+}
+
+QString SymbolPaletteItem::makeSvg(ViewLayer::ViewLayerID viewLayerID) {
 	QString path = filename();
 	QFile file(filename());
 	QString svg;
 	if (file.open(QFile::ReadOnly)) {
 		svg = file.readAll();
 		file.close();
-		return replaceTextElement(svg);
+		svg = replaceTextElement(svg);
+        if (viewLayerID == ViewLayer::SchematicText) {
+            bool hasText;
+            return SvgFileSplitter::showText3(svg, hasText);
+        }
+        else {
+            return SvgFileSplitter::hideText3(svg);
+        }
 	}
 
 	return "";
@@ -357,92 +358,15 @@ ConnectorItem * SymbolPaletteItem::connector1() {
 void SymbolPaletteItem::addedToScene(bool temporary)
 {
 	if (this->scene()) {
-		if (m_isNetLabel) {
-			setLabel(getLabel());
-		}
-		else {
-			setVoltage(m_voltage);
-		}
+		setVoltage(m_voltage);
 	}
 
     return PaletteItem::addedToScene(temporary);
 }
 
-QString SymbolPaletteItem::makeNetLabelSvg() {
-    static const double labelFontSize = 200;
-    static const double totalHeight = 300;
-    static const double arrowWidth = totalHeight / 2;
-    static const double strokeWidth = 10;
-    static const double halfStrokeWidth = strokeWidth / 2;
-    static const double labelOffset = 20;
-    static const double labelBaseLine = 220;
-
-    QFont font("Droid Sans", labelFontSize * 72 / GraphicsUtils::StandardFritzingDPI, QFont::Normal);
-	QFontMetricsF fm(font);
-    double textWidth = fm.width(getLabel()) * GraphicsUtils::StandardFritzingDPI / 72;
-    double totalWidth = textWidth + arrowWidth + labelOffset;
-
-	QString header("<?xml version='1.0' encoding='UTF-8' standalone='no'?>\n"
-					"<svg xmlns:svg='http://www.w3.org/2000/svg' xmlns='http://www.w3.org/2000/svg' version='1.2' baseProfile='tiny' \n"
-					"width='%1in' height='%2in' viewBox='0 0 %3 %4' >\n"
-					"<g id='schematic' >\n"
-                    );
-
-    bool goLeft = (getDirection() == "left");
-    double offset = goLeft ? arrowWidth : 0;
-
-    QString svg = header.arg(totalWidth / 1000).arg(totalHeight / 1000).arg(totalWidth).arg(totalHeight);
-
-    QString pin = QString("<rect id='connector0pin' x='%1' y='%2' width='%3' height='%4' fill='none' stroke='none' stroke-width='0' />\n");
-    QString terminal = QString("<rect id='connector0terminal' x='%1' y='%2' width='0.1' height='0.1' fill='none' stroke='none' stroke-width='0' />\n");
-
-    QString points = QString("%1,%2 %3,%4 %5,%4 %5,%6 %3,%6");
-    if (goLeft) {
-        points = points.arg(halfStrokeWidth).arg(totalHeight / 2)
-                        .arg(arrowWidth).arg(halfStrokeWidth)
-                        .arg(totalWidth - halfStrokeWidth).arg(totalHeight - halfStrokeWidth);
-        terminal = terminal.arg(0).arg(totalHeight / 2);
-        pin = pin.arg(0).arg(0).arg(arrowWidth).arg(totalHeight);
-    }
-    else {
-        points = points.arg(totalWidth - halfStrokeWidth).arg(totalHeight / 2)
-                        .arg(totalWidth - arrowWidth).arg(halfStrokeWidth)
-                        .arg(halfStrokeWidth).arg(totalHeight - halfStrokeWidth);
-        terminal = terminal.arg(totalWidth).arg(totalHeight / 2);
-        pin = pin.arg(totalWidth - arrowWidth - 0.1).arg(0).arg(arrowWidth).arg(totalHeight);
-    }
-
-    svg += pin;
-    svg += terminal;
-    svg += QString("<polygon fill='white' stroke='#000000' stroke-width='%1' points='%2' />\n")
-                    .arg(strokeWidth)
-                    .arg(points);
-
-    svg += QString("<text id='label' x='%1' y='%2' fill='#000000' font-family='DroidSans' font-size='%3'>%4</text>\n")
-            .arg(labelOffset + offset)
-            .arg(labelBaseLine)
-            .arg(labelFontSize)
-            .arg(getLabel());
-
-
-    svg += "</g>\n</svg>\n";
- 
-    return svg;
-}
-
-QString SymbolPaletteItem::retrieveNetLabelSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi) {
-    Q_UNUSED(svgHash);
-    QString svg = makeNetLabelSvg();
-    return PaletteItemBase::normalizeSvg(svg, viewLayerID, blackOnly, dpi);
-}
-
-QString SymbolPaletteItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi) 
+QString SymbolPaletteItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor) 
 {
-    if (m_isNetLabel) {
-        return retrieveNetLabelSvg(viewLayerID, svgHash, blackOnly, dpi);
-    }
-
-	QString svg = PaletteItem::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi);
+	QString svg = PaletteItem::retrieveSvg(viewLayerID, svgHash, blackOnly, dpi, factor);
 	if (m_voltageReference) {
 		switch (viewLayerID) {
 			case ViewLayer::Schematic:
@@ -455,7 +379,7 @@ QString SymbolPaletteItem::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash
 	return svg; 
 }
 
-bool SymbolPaletteItem::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget)
+bool SymbolPaletteItem::collectExtraInfo(QWidget * parent, const QString & family, const QString & prop, const QString & value, bool swappingEnabled, QString & returnProp, QString & returnValue, QWidget * & returnWidget, bool & hide)
 {
 	if ((prop.compare("voltage", Qt::CaseInsensitive) == 0) && 
 		(moduleID().compare(ModuleIDNames::GroundModuleIDName) != 0)) 
@@ -502,7 +426,7 @@ bool SymbolPaletteItem::collectExtraInfo(QWidget * parent, const QString & famil
 		return true;
 	}
 
-	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget);
+	return PaletteItem::collectExtraInfo(parent, family, prop, value, swappingEnabled, returnProp, returnValue, returnWidget, hide);
 }
 
 void SymbolPaletteItem::voltageEntry(const QString & text) {
@@ -531,8 +455,6 @@ void SymbolPaletteItem::labelEntry() {
 }
 
 ItemBase::PluralType SymbolPaletteItem::isPlural() {
-    if (m_isNetLabel) return Plural;
-
 	return Singular;
 }
 
@@ -541,7 +463,7 @@ bool SymbolPaletteItem::hasPartNumberProperty()
 	return false;
 }
 
-ViewLayer::ViewIdentifier SymbolPaletteItem::useViewIdentifierForPixmap(ViewLayer::ViewIdentifier vid, bool) 
+ViewLayer::ViewID SymbolPaletteItem::useViewIDForPixmap(ViewLayer::ViewID vid, bool) 
 {
     if (vid == ViewLayer::SchematicView) {
         return ViewLayer::IconView;
@@ -554,14 +476,205 @@ bool SymbolPaletteItem::hasPartLabel() {
 	return !m_isNetLabel;
 }
 
-bool SymbolPaletteItem::isNetLabel() {
-	return m_isNetLabel;
+bool SymbolPaletteItem::isOnlyNetLabel() {
+	return false;
 }
 
 QString SymbolPaletteItem::getLabel() {
+    if (m_voltageReference) {
+        return QString::number(m_voltage);
+    }
     return  modelPart()->localProp("label").toString();
 }
 
 QString SymbolPaletteItem::getDirection() {
     return  modelPart()->localProp("direction").toString();
 }
+
+void SymbolPaletteItem::setAutoroutable(bool ar) {
+	m_viewGeometry.setAutoroutable(ar);
+}
+
+bool SymbolPaletteItem::getAutoroutable() {
+	return m_viewGeometry.getAutoroutable();
+}
+
+void SymbolPaletteItem::resetLayerKin() {
+
+    foreach (ItemBase * lkpi, layerKin()) {
+        if (lkpi->viewLayerID() == ViewLayer::SchematicText) {
+	        QString svg = makeSvg(lkpi->viewLayerID());
+	        lkpi->resetRenderer(svg);
+            lkpi->setProperty("textSvg", svg);
+            qobject_cast<SchematicTextLayerKinPaletteItem *>(lkpi)->clearTextThings();
+            break;
+        }
+    }
+}
+
+///////////////////////////////////////////////////////////////
+
+NetLabel::NetLabel( ModelPart * modelPart, ViewLayer::ViewID viewID, const ViewGeometry & viewGeometry, long id, QMenu * itemMenu, bool doLabel)
+	: SymbolPaletteItem(modelPart, viewID, viewGeometry, id, itemMenu, doLabel)
+{
+	QString label = getLabel();
+	if (label.isEmpty()) {
+		label = modelPart->properties().value("label");
+		if (label.isEmpty()) {
+			label = tr("net label");
+		}
+		modelPart->setLocalProp("label", label);
+	}
+    setInstanceTitle(label, true);
+
+    // direction is now obsolete, new netlabels use flip
+	QString direction = getDirection();
+	if (direction.isEmpty()) {
+		direction = modelPart->properties().value("direction");
+		if (direction.isEmpty()) {
+			direction = modelPart->moduleID().contains("left", Qt::CaseInsensitive) ? "left" : "right";
+		}
+		modelPart->setLocalProp("direction", direction);
+	}
+}
+
+NetLabel::~NetLabel() {
+}
+
+QString NetLabel::makeSvg(ViewLayer::ViewLayerID viewLayerID) {
+
+    DebugDialog::debug("moduleid " + this->moduleID());
+    double divisor = moduleID().contains(PartFactory::OldSchematicPrefix) ? 1 : 3;
+
+    double labelFontSize = 200 /divisor;
+    double totalHeight = 300 / divisor;
+    double arrowWidth = totalHeight / 2;
+    double strokeWidth = 10 / divisor;
+    double halfStrokeWidth = strokeWidth / 2;
+    double labelOffset = 20 / divisor;
+    double labelBaseLine = 220 / divisor;
+
+    QFont font("Droid Sans", labelFontSize * 72 / GraphicsUtils::StandardFritzingDPI, QFont::Normal);
+	QFontMetricsF fm(font);
+    double textWidth = fm.width(getLabel()) * GraphicsUtils::StandardFritzingDPI / 72;
+    double totalWidth = textWidth + arrowWidth + labelOffset;
+
+	QString header("<?xml version='1.0' encoding='UTF-8' standalone='no'?>\n"
+					"<svg xmlns:svg='http://www.w3.org/2000/svg' xmlns='http://www.w3.org/2000/svg' version='1.2' baseProfile='tiny' \n"
+					"width='%1in' height='%2in' viewBox='0 0 %3 %4' >\n"
+					"<g id='%5' >\n"
+                    );
+
+    bool goLeft = (getDirection() == "left");  // direction is now obsolete; this is left over from 0.7.12 and earlier
+    double offset = goLeft ? arrowWidth : 0;
+
+    QString svg = header.arg(totalWidth / 1000)
+            .arg(totalHeight / 1000)
+            .arg(totalWidth)
+            .arg(totalHeight)
+            .arg(ViewLayer::viewLayerXmlNameFromID(viewLayerID))
+            ;
+
+    if (viewLayerID == ViewLayer::SchematicText) {
+        svg += QString("<text id='label' x='%1' y='%2' fill='#000000' font-family='Droid Sans' font-size='%3'>%4</text>\n")
+                .arg(labelOffset + offset)
+                .arg(labelBaseLine)
+                .arg(labelFontSize)
+                .arg(getLabel());
+    }
+    else {
+        QString pin = QString("<rect id='connector0pin' x='%1' y='%2' width='%3' height='%4' fill='none' stroke='none' stroke-width='0' />\n");
+        QString terminal = QString("<rect id='connector0terminal' x='%1' y='%2' width='0.1' height='0.1' fill='none' stroke='none' stroke-width='0' />\n");
+
+        QString points = QString("%1,%2 %3,%4 %5,%4 %5,%6 %3,%6");
+        if (goLeft) {
+            points = points.arg(halfStrokeWidth).arg(totalHeight / 2)
+                            .arg(arrowWidth).arg(halfStrokeWidth)
+                            .arg(totalWidth - halfStrokeWidth).arg(totalHeight - halfStrokeWidth);
+            terminal = terminal.arg(0).arg(totalHeight / 2);
+            pin = pin.arg(0).arg(0).arg(arrowWidth).arg(totalHeight);
+        }
+        else {
+            points = points.arg(totalWidth - halfStrokeWidth).arg(totalHeight / 2)
+                            .arg(totalWidth - arrowWidth).arg(halfStrokeWidth)
+                            .arg(halfStrokeWidth).arg(totalHeight - halfStrokeWidth);
+            terminal = terminal.arg(totalWidth).arg(totalHeight / 2);
+            pin = pin.arg(totalWidth - arrowWidth - 0.1).arg(0).arg(arrowWidth).arg(totalHeight);
+        }
+
+        svg += pin;
+        svg += terminal;
+        svg += QString("<polygon fill='white' stroke='#000000' stroke-width='%1' points='%2' />\n")
+                        .arg(strokeWidth)
+                        .arg(points);
+    }
+
+    svg += "</g>\n</svg>\n";
+ 
+    return svg;
+}
+
+void NetLabel::addedToScene(bool temporary)
+{
+	if (this->scene() && m_viewID == ViewLayer::SchematicView) {
+        // do not understand why plan setLabel() doesn't work the same as the Mystery Part setChipLabel() in addedToScene()
+
+        if (!this->transform().isIdentity()) {
+            // need to establish correct bounding rect here or setLabel will screw up alignment
+            // this seems to solve half of the cases
+	        QString svg = makeSvg(this->viewLayerID());
+	        resetRenderer(svg);
+            resetLayerKin();
+            QRectF r = boundingRect();
+            //debugInfo(QString("added to scene %1,%2").arg(r.width()).arg(r.height()));
+
+
+            QTransform chiefTransform = this->transform();
+            QTransform local;
+            local.setMatrix(chiefTransform.m11(), chiefTransform.m12(), chiefTransform.m13(), chiefTransform.m21(), chiefTransform.m22(), chiefTransform.m23(), 0, 0, chiefTransform.m33()); 
+            if (!local.isIdentity()) {    
+                double x = r.width() / 2.0;
+	            double y = r.height() / 2.0;
+	            QTransform transf = QTransform().translate(-x, -y) * local * QTransform().translate(x, y);
+                if (qAbs(chiefTransform.dx() - transf.dx()) > .01 || qAbs(chiefTransform.dy() - transf.dy()) > .01) {
+                    DebugDialog::debug("got the translation bug here");
+                    this->getViewGeometry().setTransform(transf);
+                    this->setTransform2(transf);
+                }
+            }
+        }
+
+		setLabel(getLabel());
+
+	}
+
+    // deliberately skip SymbolPaletteItem::addedToScene()
+    return PaletteItem::addedToScene(temporary);
+}
+
+QString NetLabel::retrieveSvg(ViewLayer::ViewLayerID viewLayerID, QHash<QString, QString> & svgHash, bool blackOnly, double dpi, double & factor) {
+    Q_UNUSED(svgHash);
+    QString svg = makeSvg(viewLayerID);
+    return PaletteItemBase::normalizeSvg(svg, viewLayerID, blackOnly, dpi, factor);
+}
+
+ItemBase::PluralType NetLabel::isPlural() {
+	return Plural;
+}
+
+bool NetLabel::isOnlyNetLabel() {
+	return true;
+}
+
+QString NetLabel::getInspectorTitle() {
+   return getLabel();
+
+}
+
+void NetLabel::setInspectorTitle(const QString & oldText, const QString & newText) {
+    InfoGraphicsView * infoGraphicsView = InfoGraphicsView::getInfoGraphicsView(this);
+    if (infoGraphicsView == NULL) return;
+
+    infoGraphicsView->setProp(this, "label", ItemBase::TranslatedPropertyNames.value("label"), oldText, newText, true);
+}
+
