@@ -1,7 +1,7 @@
 /*******************************************************************
 skw
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2014 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,10 +24,17 @@ $Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
-#include <QtGui>
+#include <QtCore>
+
 #include <QSvgGenerator>
 #include <QColor>
 #include <QImageWriter>
+#include <QPrinter>
+#include <QSettings>
+#include <QDesktopServices>
+#include <QPrintDialog>
+#include <QClipboard>
+#include <QApplication>
 
 #include "mainwindow.h"
 #include "../debugdialog.h"
@@ -39,6 +46,7 @@ $Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 #include "../items/via.h"
 #include "../fsvgrenderer.h"
 #include "../items/note.h"
+#include "../items/partfactory.h"
 #include "../eagle/fritzing2eagle.h"
 #include "../sketch/breadboardsketchwidget.h"
 #include "../sketch/schematicsketchwidget.h"
@@ -58,7 +66,6 @@ $Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 #include "../utils/textutils.h"
 #include "../connectors/ercdata.h"
 #include "../items/moduleidnames.h"
-#include "../dock/miniviewcontainer.h"
 #include "../utils/zoomslider.h"
 #include "../dock/layerpalette.h"
 #include "../program/programwindow.h"
@@ -69,7 +76,9 @@ $Date: 2013-04-22 23:44:56 +0200 (Mo, 22. Apr 2013) $
 static QString eagleActionType = ".eagle";
 static QString gerberActionType = ".gerber";
 static QString jpgActionType = ".jpg";
+#if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
 static QString psActionType = ".ps";
+#endif
 static QString pdfActionType = ".pdf";
 static QString pngActionType = ".png";
 static QString svgActionType = ".svg";
@@ -118,20 +127,24 @@ bool sortPartList(ItemBase * b1, ItemBase * b2) {
 
 void MainWindow::initNames()
 {
-	OtherKnownExtensions << jpgActionType << psActionType << pdfActionType << pngActionType << svgActionType << bomActionType << netlistActionType << spiceNetlistActionType;
+	OtherKnownExtensions << jpgActionType << pdfActionType << pngActionType << svgActionType << bomActionType << netlistActionType << spiceNetlistActionType;
 
 	filePrintFormats[pdfActionType] = QPrinter::PdfFormat;
-	filePrintFormats[psActionType] = QPrinter::PostScriptFormat;
 
 	fileExportFormats[pngActionType] = QImage::Format_ARGB32;
 	fileExportFormats[jpgActionType] = QImage::Format_RGB32;
 
 	fileExtFormats[pdfActionType] = tr("PDF (*.pdf)");
-	fileExtFormats[psActionType] = tr("PostScript (*.ps)");
 	fileExtFormats[pngActionType] = tr("PNG Image (*.png)");
 	fileExtFormats[jpgActionType] = tr("JPEG Image (*.jpg)");
 	fileExtFormats[svgActionType] = tr("SVG Image (*.svg)");
 	fileExtFormats[bomActionType] = tr("BoM Text File (*.html)");
+    
+#if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
+    OtherKnownExtensions << psActionType;
+	filePrintFormats[psActionType] = QPrinter::PostScriptFormat;
+	fileExtFormats[psActionType] = tr("PostScript (*.ps)");
+#endif
 
 	QSettings settings;
 	AutosaveEnabled = settings.value("autosaveEnabled", QString("%1").arg(AutosaveEnabled)).toBool();
@@ -139,6 +152,8 @@ void MainWindow::initNames()
 }
 
 void MainWindow::print() {
+    if (m_currentGraphicsView == NULL) return;
+
 	#ifndef QT_NO_PRINTER
 		QPrinter printer(QPrinter::HighResolution);
 
@@ -551,6 +566,8 @@ void MainWindow::doExport() {
 
 void MainWindow::exportAux(QString fileName, QImage::Format format, int quality, bool removeBackground) 
 {
+    if (m_currentGraphicsView == NULL) return;
+
     double resMultiplier = 3;
 
     QRectF itemsBoundingRect;
@@ -620,6 +637,8 @@ void MainWindow::exportAux(QString fileName, QImage::Format format, int quality,
 }
 
 void MainWindow::printAux(QPrinter &printer, bool removeBackground, bool paginate) {
+    if (m_currentGraphicsView == NULL) return;
+
 	int res = printer.resolution();
 	double scale2 = res / GraphicsUtils::SVGDPI;
 	DebugDialog::debug(QString("p.w:%1 p.h:%2 pager.w:%3 pager.h:%4 paperr.w:%5 paperr.h:%6 source.w:%7 source.h:%8")
@@ -823,6 +842,7 @@ void MainWindow::saveAsShareable(const QString & path, bool saveModel)
             continue;
         }
 		if (itemBase->modelPart()->isCore()) continue;
+        if (itemBase->moduleID().contains(PartFactory::OldSchematicPrefix)) continue;
 	
 		saveParts.insert(itemBase->moduleID(), itemBase->modelPart());
 	}
@@ -872,7 +892,7 @@ void MainWindow::saveBundledNonAtomicEntity(QString &filename, const QString &ex
 			LinkedFile * linkedFile = m_linkedProgramFiles.at(i);
 			QFileInfo fileInfo(linkedFile->linkedFilename);
 			QFile file(linkedFile->linkedFilename);
-			file.copy(destFolder.absoluteFilePath(fileInfo.fileName()));
+			FolderUtils::slamCopy(file, destFolder.absoluteFilePath(fileInfo.fileName()));
 		}
         skipSuffixes << FritzingBinExtension << FritzingBundleExtension;
 	}
@@ -942,10 +962,12 @@ void MainWindow::createExportActions() {
 	m_exportPngAct->setStatusTip(tr("Export the visible area of the current sketch as a PNG image"));
 	connect(m_exportPngAct, SIGNAL(triggered()), this, SLOT(doExport()));
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 	m_exportPsAct = new QAction(tr("PostScript..."), this);
 	m_exportPsAct->setData(psActionType);
 	m_exportPsAct->setStatusTip(tr("Export the visible area of the current sketch as a PostScript image"));
 	connect(m_exportPsAct, SIGNAL(triggered()), this, SLOT(doExport()));
+#endif
 
 	m_exportPdfAct = new QAction(tr("PDF..."), this);
 	m_exportPdfAct->setData(pdfActionType);
@@ -1391,6 +1413,50 @@ void MainWindow::exportSpiceNetlist() {
         output += "\n";
     }
 
+    QString incl = ".include";
+    if (output.contains(incl, Qt::CaseInsensitive)) {
+        QStringList lines = output.split("\n");
+        QList<QDir *> paths;
+        paths << FolderUtils::getApplicationSubFolder("pdb");
+        paths << FolderUtils::getApplicationSubFolder("parts");
+        paths << new QDir(FolderUtils::getUserDataStorePath("parts"));
+
+        QString output2;
+        foreach (QString line, lines) {
+            int ix = line.toLower().indexOf(incl); 
+            if (ix < 0) {
+                output2 += line + "\n";
+                continue;
+            }
+
+            QString temp = line;
+            temp.replace(ix, incl.length(), "");
+            QString filename = temp.trimmed();
+            
+            bool gotOne = false;
+            foreach (QDir * dir, paths) {
+                foreach (QString folder, ModelPart::possibleFolders()) {
+                    QDir sub(*dir);
+                    sub.cd(folder);
+                    sub.cd("spicemodels");
+                    if (QFile::exists(sub.absoluteFilePath(filename))) {
+                        output2 += incl.toUpper() + " " + QDir::toNativeSeparators(sub.absoluteFilePath(filename)) + "\n";
+                        gotOne = true;
+                        break;
+                    }
+                }
+                if (gotOne) break;
+            }
+
+            // can't find the include file, so just restore the original line
+            if (!gotOne) {
+                output2 += line + "\n";
+            }
+        }
+
+        output = output2;
+        foreach (QDir * dir, paths) delete dir;
+    }
 
     output += ".TRAN 1ms 100ms\n";
     output += "* .AC DEC 100 100 1MEG\n";
@@ -1638,3 +1704,33 @@ void MainWindow::massageOutput(QString & svg, bool doMask, bool doSilk, bool doP
 		svg = TextUtils::expandAndFill(svg, "black", GerberGenerator::MaskClearanceMils * 2 * dpi / 1000);
 	}
 }
+
+void MainWindow::dumpAllParts() {
+    if (m_currentGraphicsView == NULL) return;
+
+    QList<ItemBase *> already;
+    foreach (QGraphicsItem * item, m_currentGraphicsView->items()) {
+        ItemBase * ib = dynamic_cast<ItemBase *>(item);
+        if (ib == NULL) continue;
+
+        ItemBase * chief = ib->layerKinChief();
+        if (already.contains(chief)) continue;
+
+        already << chief;
+
+        QList<ItemBase *> itemBases;
+        itemBases << chief;
+        itemBases.append(chief->layerKin());
+        foreach (ItemBase * itemBase, itemBases) {
+            itemBase->debugInfo("");
+            foreach (ConnectorItem * connectorItem, itemBase->cachedConnectorItems()) {
+                if (connectorItem->connectionsCount() > 0) {
+                    connectorItem->debugInfo("\t");
+                    foreach (ConnectorItem * to, connectorItem->connectedToItems()) {
+                        to->debugInfo("\t\t");
+                    }
+                }
+            }
+        }
+    }
+}
