@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6494 $:
+$Revision: 6912 $:
 $Author: irascibl@gmail.com $:
-$Date: 2012-09-29 17:40:27 +0200 (Sat, 29 Sep 2012) $
+$Date: 2013-03-09 08:18:59 +0100 (Sa, 09. Mrz 2013) $
 
 ********************************************************************/
 
@@ -54,7 +54,7 @@ class SvgIconWidget : public QGraphicsWidget
 {
 Q_OBJECT
 public:
-	SvgIconWidget(ModelPart *, ViewLayer::ViewIdentifier, ItemBase *, bool plural);
+	SvgIconWidget(ModelPart *, ViewLayer::ViewID, ItemBase *, bool plural);
 	~SvgIconWidget();
 	ItemBase * itemBase() const;
 	ModelPart * modelPart() const;
@@ -68,7 +68,7 @@ protected:
 	void hoverEnterEvent ( QGraphicsSceneHoverEvent * event );
 	void hoverLeaveEvent ( QGraphicsSceneHoverEvent * event );
 	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
-	void setupImage(bool plural, ViewLayer::ViewIdentifier viewIdentifier);
+	void setupImage(bool plural, ViewLayer::ViewID viewID);
 
 protected:
 	QPointer<ItemBase> m_itemBase;
