@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2014 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6469 $:
+$Revision: 6904 $:
 $Author: irascibl@gmail.com $:
-$Date: 2012-09-23 00:54:30 +0200 (Sun, 23 Sep 2012) $
+$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 
 ********************************************************************/
 
@@ -33,14 +33,17 @@ $Date: 2012-09-23 00:54:30 +0200 (Sun, 23 Sep 2012) $
 #include <QFileInfoList>
 #include <QFileInfo>
 #include <QRegExp>
-#include <QtGui>
 #include <QSettings>
 #include <QFontMetrics>
 #include <QTextStream>
 #include <QMessageBox>
 #include <QSplitter>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+
 
 static const QChar Quote91Char(0x91);
+static QString UnableToProgramMessage;
 
 /////////////////////////////////////////
 
@@ -116,7 +119,11 @@ QIcon * AsteriskIcon = NULL;
 
 ProgramTab::ProgramTab(QString & filename, QWidget *parent) : QFrame(parent)
 {
-	m_tabWidget = NULL;
+    if (UnableToProgramMessage.isEmpty()) {
+        UnableToProgramMessage = tr("While it is possible to read and edit %1 programming files, it is not yet possible to use Fritzing to compile or upload these programs to a microcontroller.");
+    }
+
+    m_tabWidget = NULL;
 	while (parent != NULL) {
 		QTabWidget * tabWidget = qobject_cast<QTabWidget *>(parent);
 		if (tabWidget) {
@@ -143,7 +150,10 @@ ProgramTab::ProgramTab(QString & filename, QWidget *parent) : QFrame(parent)
 	editLayout->setMargin(0);
 	editLayout->setSpacing(0);
 
-    m_programWindow = qobject_cast<ProgramWindow *>(window());
+    while (m_programWindow == NULL) {
+        m_programWindow = qobject_cast<ProgramWindow *>(parent);
+        parent = parent->parentWidget();
+    }
 
     // m_textEdit needs to be initialized before createFooter so
     // some signals get connected properly.
@@ -195,6 +205,8 @@ void ProgramTab::showEvent(QShowEvent *event) {
 }
 
 QFrame * ProgramTab::createFooter() {
+    QFrame * superFrame = new QFrame();
+
     QFrame * footerFrame = new QFrame();
     footerFrame->setObjectName("footer"); // Used for styling
 	footerFrame->setSizePolicy(QSizePolicy::Preferred,QSizePolicy::Fixed);
@@ -210,7 +222,6 @@ QFrame * ProgramTab::createFooter() {
 	if (currentLanguage.isEmpty()) {
 		currentLanguage = m_languageComboBox->currentText();
 	}
-    setLanguage(currentLanguage, false);
 
 	QPushButton * addButton = new QPushButton(tr("New"));
 	//addButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -286,9 +297,21 @@ QFrame * ProgramTab::createFooter() {
     connect(m_languageComboBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(setLanguage(const QString &)));
     connect(m_portComboBox, SIGNAL(currentIndexChanged(const QString &)), this, SLOT(setPort(const QString &)));
 	connect(m_portComboBox, SIGNAL(aboutToShow()), this, SLOT(updateSerialPorts()), Qt::DirectConnection);
-    connect(m_programmerComboBox, SIGNAL(activated(int)), this, SLOT(chooseProgrammerTimed(int)));	
+    connect(m_programmerComboBox, SIGNAL(activated(int)), this, SLOT(chooseProgrammerTimed(int)));
 
-	return footerFrame;
+    QVBoxLayout * superLayout = new QVBoxLayout();
+	superLayout->setMargin(0);
+	superLayout->setSpacing(0);
+
+    m_unableToProgramLabel = new QLabel(UnableToProgramMessage.arg(""));
+    m_unableToProgramLabel->setObjectName("unableToProgramLabel");
+    superLayout->addWidget(footerFrame);
+    superLayout->addWidget(m_unableToProgramLabel);
+    superFrame->setLayout(superLayout);
+
+    setLanguage(currentLanguage, false);
+
+	return superFrame;
 }
 
 void ProgramTab::setLanguage(const QString & newLanguage) {
@@ -296,18 +319,23 @@ void ProgramTab::setLanguage(const QString & newLanguage) {
 }
 
 void ProgramTab::setLanguage(const QString & newLanguage, bool updateLink) {
-        DebugDialog::debug(QString("Setting language to %1").arg(newLanguage));
-		if (updateLink && newLanguage != m_language) {
-			m_programWindow->updateLink(m_filename, newLanguage, m_programmerPath, false, false);
-		}
+    DebugDialog::debug(QString("Setting language to %1").arg(newLanguage));
+	if (updateLink && newLanguage != m_language) {
+		m_programWindow->updateLink(m_filename, newLanguage, m_programmerPath, false, false);
+	}
 
-        m_language = newLanguage;
-        m_languageComboBox->setCurrentIndex(m_languageComboBox->findText(newLanguage));
-        m_highlighter->setSyntaxer(m_programWindow->getSyntaxerForLanguage(newLanguage));
-		m_highlighter->rehighlight();
-        updateMenu();
-		QSettings settings;
-		settings.setValue("programwindow/language", newLanguage);
+    m_language = newLanguage;
+    m_languageComboBox->setCurrentIndex(m_languageComboBox->findText(newLanguage));
+    Syntaxer * syntaxer = m_programWindow->getSyntaxerForLanguage(newLanguage);
+    m_highlighter->setSyntaxer(syntaxer);
+	m_highlighter->rehighlight();
+    updateMenu();
+	QSettings settings;
+	settings.setValue("programwindow/language", newLanguage);
+
+    bool canProgram = (syntaxer != NULL && syntaxer->canProgram());
+    m_unableToProgramLabel->setVisible(!canProgram);
+    m_unableToProgramLabel->setText(UnableToProgramMessage.arg(newLanguage));
 }
 
 void ProgramTab::setPort(const QString & newPort) {
@@ -339,10 +367,13 @@ bool ProgramTab::loadProgramFile() {
 }
 
 bool ProgramTab::loadProgramFile(const QString & fileName, const QString & altFileName, bool updateLink) {
+    DebugDialog::debug("program tab load program file");
 	if (m_programWindow->alreadyHasProgram(fileName)) {
 		return false;
 	}
 
+    DebugDialog::debug("checking file");
+
 	QFile file(fileName);
 	if (!file.open(QFile::ReadOnly)) {
 		m_programWindow->updateLink(fileName, m_language, m_programmerPath, false, true);
@@ -354,7 +385,7 @@ bool ProgramTab::loadProgramFile(const QString & fileName, const QString & altFi
 										NULL,
 										tr("Fritzing is unable to find '%1', please locate it").arg(fileInfo.fileName()),
 										FolderUtils::openSaveFolder(),
-										tr("Program (*.%1)").arg(fileInfo.suffix())
+										tr("Code (*.%1)").arg(fileInfo.suffix())
 								);
 				if (fn.isEmpty()) return false;
 
@@ -366,6 +397,8 @@ bool ProgramTab::loadProgramFile(const QString & fileName, const QString & altFi
 		}
 	}
 
+    DebugDialog::debug("about to read");
+
 	m_filename = file.fileName();
 	QString text = file.readAll();
 	// clean out 0x91, mostly due to picaxe files
@@ -374,11 +407,17 @@ bool ProgramTab::loadProgramFile(const QString & fileName, const QString & altFi
 			text[i] = '\'';
 		}
 	}
+
+    DebugDialog::debug("about to set text");
+
 	m_textEdit->setText(text);
 	setClean();
 	QFileInfo fileInfo(m_filename);
 	m_tabWidget->setTabText(m_tabWidget->currentIndex(), fileInfo.fileName());
 	m_tabWidget->setTabToolTip(m_tabWidget->currentIndex(), m_filename);
+
+    DebugDialog::debug("about to update link");
+
 	if (updateLink) {
 		m_programWindow->updateLink(m_filename, m_language, m_programmerPath, true, true);
 	}
@@ -601,6 +640,27 @@ void ProgramTab::sendProgram() {
 		m_console->setPlainText("");
 		
         process->start(m_programmerPath, args);
+        return;
+	}
+
+	if (language.compare("arduino", Qt::CaseInsensitive) == 0) {
+        return;         // not yet implemented
+
+		QProcess * process = new QProcess(this);
+		process->setProcessChannelMode(QProcess::MergedChannels);
+		process->setReadChannel(QProcess::StandardOutput);
+
+		connect(process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(programProcessFinished(int, QProcess::ExitStatus)));
+		connect(process, SIGNAL(readyReadStandardOutput()), this, SLOT(programProcessReadyRead()));
+
+		QStringList args;
+		args.append(QString("--upload --verbose --board arduino:arduino:uno"));
+        QString temp = m_filename;
+		args.append(QDir::toNativeSeparators(m_filename));
+		m_console->setPlainText("");
+		
+        process->start(m_programmerPath, args);
+        return;
 	}
 
 }
@@ -804,7 +864,8 @@ void ProgramTab::enableProgramButton() {
 	}
 	if (enabled && m_portComboBox->count() == 1) {
 		if (m_portComboBox->itemText(0).compare(ProgramWindow::NoSerialPortName) == 0) {
-			enabled = false;
+            DebugDialog::debug("restore enabled please");
+			//enabled = false;
 		}
 	}
 	if (enabled && m_textEdit->document()->isEmpty()) {
