@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 $Revision: 6112 $:
 $Author: cohen@irascible.com $:
-$Date: 2012-06-28 00:18:10 +0200 (Thu, 28 Jun 2012) $
+$Date: 2012-06-28 00:18:10 +0200 (Do, 28. Jun 2012) $
 
 ********************************************************************/
 
@@ -85,6 +85,7 @@ bool Syntaxer::loadSyntax(const QString &filename)
 		context = context.nextSiblingElement("context");
 	}
 
+    m_canProgram = root.attribute("canProgram", "").compare("true", Qt::CaseInsensitive) == 0;
 	m_name = root.attribute("name");
 	QStringList extensions = root.attribute("extensions").split(";", QString::SkipEmptyParts);
 	if (extensions.count() > 0) {
@@ -238,6 +239,12 @@ bool Syntaxer::hlCStringChar() {
 	return m_hlCStringChar;
 }
 
+
+bool Syntaxer::canProgram() {
+    return m_canProgram;
+}
+
+
 //////////////////////////////////////////////
 
 SyntaxerTrieLeaf::SyntaxerTrieLeaf(QString name) {
@@ -261,4 +268,3 @@ CommentInfo::CommentInfo(const QString & start, const QString & end, Qt::CaseSen
 	m_multiLine = !end.isEmpty();
 	m_caseSensitive = caseSensitive;
 }
-
