@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6483 $:
+$Revision: 6955 $:
 $Author: irascibl@gmail.com $:
-$Date: 2012-09-26 15:45:37 +0200 (Wed, 26 Sep 2012) $
+$Date: 2013-04-06 23:14:37 +0200 (Sa, 06. Apr 2013) $
 
 ********************************************************************/
 
@@ -41,7 +41,7 @@ class SqliteReferenceModel : public ReferenceModel {
 		SqliteReferenceModel();
 		~SqliteReferenceModel();
 
-		bool loadAll(const QString & databaseName, bool fullLoad);
+		bool loadAll(const QString & databaseName, bool fullLoad, bool dbExists);
 		bool loadFromDB(const QString & databaseName);
 		ModelPart *loadPart(const QString & path, bool update);
 		ModelPart *reloadPart(const QString & path, const QString & moduleID);
@@ -64,7 +64,7 @@ class SqliteReferenceModel : public ReferenceModel {
 		bool lastWasExactMatch();
 
 	protected:
-		void initParts();
+		void initParts(bool dbExists);
         void killParts();
 
 	protected:
@@ -78,19 +78,23 @@ class SqliteReferenceModel : public ReferenceModel {
 		bool createConnection(const QString & databaseName, bool fullLoad);
 		void deleteConnection();
 		bool insertPart(ModelPart *, bool fullLoad);
-		bool insertProperty(const QString & name, const QString & value, qulonglong id);
+		bool insertProperty(const QString & name, const QString & value, qulonglong id, bool showInLabel);
 		bool insertTag(const QString & tag, qulonglong id);
 		bool insertViewImage(const struct ViewImage *, qulonglong id);
         bool insertConnector(const class Connector *, qulonglong id);
-        bool insertConnectorLayer(const struct SvgIdLayer *, qulonglong id);  // connector db id
-        bool insertBus(const Bus * bus, qulonglong id);
-        bool insertBusMember(const Connector * connector, qulonglong id);
+        bool insertConnectorLayer(const class SvgIdLayer *, qulonglong id);  // connector db id
+        bool insertBus(const Bus *, qulonglong id);
+        bool insertBusMember(const Connector *, qulonglong id);
 		qulonglong partId(QString moduleID);
 		bool removePart(qulonglong partId);
 		bool removeProperties(qulonglong partId);
         bool loadFromDB(QSqlDatabase & keep_db, QSqlDatabase & db);
-        bool createProperties(QSqlDatabase & db);
-        bool createParts(QSqlDatabase & db, bool fullLoad);
+        bool createProperties(QSqlDatabase &);
+        bool createParts(QSqlDatabase &, bool fullLoad);
+        bool insertSubpart(ModelPartShared *, qulonglong id);
+        bool insertSubpartConnector(const ConnectorShared * cs, qulonglong id);
+        void createIndexes();
+        void createMoreIndexes(QSqlDatabase &);
 
 protected:
 		volatile bool m_swappingEnabled;
