@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 6563 $:
+$Revision: 6980 $:
 $Author: irascibl@gmail.com $:
-$Date: 2012-10-13 10:32:03 +0200 (Sat, 13 Oct 2012) $
+$Date: 2013-04-22 01:45:43 +0200 (Mo, 22. Apr 2013) $
 
 ********************************************************************/
 
@@ -59,7 +59,7 @@ public:
 	bool splitString(QString & contents, const QString & elementID);
 	const QByteArray & byteArray();
 	const QDomDocument & domDocument();
-	bool normalize(double dpi, const QString & elementID, bool blackOnly);
+	bool normalize(double dpi, const QString & elementID, bool blackOnly, double & factor);
 	QString shift(double x, double y, const QString & elementID, bool shiftTransforms);
 	QString elementString(const QString & elementID);
     virtual bool parsePath(const QString & data, const char * slot, PathUserData &, QObject * slotTarget, bool convertHV);
@@ -77,11 +77,17 @@ public:
 	static bool getSvgSizeAttributes(const QString & svg, QString & width, QString & height, QString & viewBox);
 	static bool changeStrokeWidth(const QString & svg, double delta, bool absolute, bool changeOpacity, QByteArray &);
 	static void changeStrokeWidth(QDomElement & element, double delta, bool absolute, bool changeOpacity);
-	static void forceStrokeWidth(QDomElement & element, double delta, const QString & stroke, bool recurse);
+	static void forceStrokeWidth(QDomElement & element, double delta, const QString & stroke, bool recurse, bool fill);
 	static bool changeColors(const QString & svg, QString & toColor, QStringList & exceptions, QByteArray &);
 	static void changeColors(QDomElement & element, QString & toColor, QStringList & exceptions);
 	static void fixStyleAttributeRecurse(QDomElement & element);
 	static void fixColorRecurse(QDomElement & element, const QString & newColor, const QStringList & exceptions);
+    static QByteArray hideText(const QString & filename);
+    static QByteArray showText(const QString & filename, bool & hasText);
+    static QByteArray hideText2(const QByteArray & svg);
+    static QByteArray showText2(const QByteArray & svg, bool & hasText);
+    static QString hideText3(const QString & svg);
+    static QString showText3(const QString & svg, bool & hasText);
 
 protected:
 	void normalizeChild(QDomElement & childElement, 
@@ -98,6 +104,8 @@ protected:
 protected:
 	static bool shiftAttribute(QDomElement & element, const char * attributeName, double d);
 	static void setStrokeOrFill(QDomElement & element, bool doIt, const QString & color, bool force);
+    static void hideTextAux(QDomElement & parent, bool hideChildren);
+    static void showTextAux(QDomElement & parent, bool & hasText, bool root);
 
 protected slots:
 	void normalizeCommandSlot(QChar command, bool relative, QList<double> & args, void * userData);
