@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2013 Fachhochschule Potsdam - http://fh-potsdam.de
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@ along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
 ********************************************************************
 
-$Revision: 5859 $:
-$Author: cohen@irascible.com $:
-$Date: 2012-02-13 13:29:26 +0100 (Mon, 13 Feb 2012) $
+$Revision: 6912 $:
+$Author: irascibl@gmail.com $:
+$Date: 2013-03-09 08:18:59 +0100 (Sa, 09. Mrz 2013) $
 
 ********************************************************************/
 
@@ -50,6 +50,7 @@ public:
 	static double pixels2mils(double p, double dpi);
 	static double pixels2ins(double p, double dpi);
 	static double distanceSqd(QPointF p1, QPointF p2);
+	static double distanceSqd(QPoint p1, QPoint p2);
 	static double getNearestOrdinate(double ordinate, double units);
 
 	static double mm2mils(double mm);
@@ -68,12 +69,16 @@ public:
 	static QPainterPath shapeFromPath(const QPainterPath &path, const QPen &pen, double shapeStrokeWidth, bool includeOriginalPath);
 	static void qt_graphicsItem_highlightSelected(QPainter *painter, const QStyleOptionGraphicsItem *option, const QRectF & boundingRect, const QPainterPath & path);
 	static QPointF calcRotation(QTransform & rotation, QPointF rCenter, QPointF p, QPointF pCenter); 
+    static void drawBorder(QImage * image, int border);
+    static bool isFlipped(const QMatrix & matrix, double & rotation);
 
 public:
-	static const int IllustratorDPI = 72;
-	static const int StandardFritzingDPI = 1000;
+	static const double IllustratorDPI;
+	static const double StandardFritzingDPI;
+	static const double SVGDPI;
 	static const double InchesPerMeter;
 	static const double StandardSchematicSeparationMils;
+	static const double StandardSchematicSeparation10thinMils;
 
 
 };
